#include <stdio.h>
#include <stdlib.h>
#include "egdb.h"

//#define ITALIAN_RULES

#ifdef ITALIAN_RULES
#define DB_PATH "c:/db_italian/wld_v2"
#else
#define DB_PATH "c:/db_english/wld_v2"
#endif

struct TEST_POSITION {
	char *fen;
	int npieces;
	int color;
	int value;
	EGDB_BITBOARD pos;
};


extern TEST_POSITION positions[];
extern const int num_positions;


void print_msgs(char *msg)
{
	printf("%s", msg);
}


int main()
{
	int i, status, max_pieces, value, nerrors;
	EGDB_TYPE egdb_type;
	EGDB_DRIVER *handle;

	/* Check that db files are present, get db type and size. */
	status = egdb_identify(DB_PATH, &egdb_type, &max_pieces);
	if (status) {
		printf("No database found at %s\n", DB_PATH);
		return(1);
	}
	printf("Database type %d found with max pieces %d\n", egdb_type, max_pieces);

	/* Open database for probing. */
	handle = egdb_open(EGDB_NORMAL, max_pieces, 2000, DB_PATH, print_msgs);
	if (!handle) {
		printf("Error returned from egdb_open()\n");
		return(1);
	}

	/* Lookup each test position, verify the WLD value. */
	nerrors = 0;
	printf("\nTesting positions.\n");
	for (i = 0; i < num_positions; ++i) {
		if (positions[i].npieces > max_pieces)
			break;

		value = handle->lookup(handle, &positions[i].pos, positions[i].color, 0);
		if (value != positions[i].value) {
			printf("%d: lookup error, expected %d, got %d\n", i, value, positions[i].value);
			++nerrors;
		}
	}
	printf("Tested %d positions, %d errors.\n", i, nerrors);

	handle->close(handle);
    return(0);
}


TEST_POSITION positions[] = {
#ifndef ITALIAN_RULES
	"B:WK2:BK17", 2, EGDB_BLACK, EGDB_DRAW, {0x00010000, 0x00000002, 0x00010002},
	"W:WK2:BK17", 2, EGDB_WHITE, EGDB_DRAW, {0x00010000, 0x00000002, 0x00010002},
	"B:W18:BK2", 2, EGDB_BLACK, EGDB_DRAW, {0x00000002, 0x00020000, 0x00000002},
	"W:W18:BK2", 2, EGDB_WHITE, EGDB_LOSS, {0x00000002, 0x00020000, 0x00000002},
	"B:W21:B10", 2, EGDB_BLACK, EGDB_WIN, {0x00000200, 0x00100000, 0x00000000},
	"W:W21:B10", 2, EGDB_WHITE, EGDB_DRAW, {0x00000200, 0x00100000, 0x00000000},
	"B:WK2:BK18,K23", 3, EGDB_BLACK, EGDB_WIN, {0x00420000, 0x00000002, 0x00420002},
	"W:WK2:BK18,K23", 3, EGDB_WHITE, EGDB_LOSS, {0x00420000, 0x00000002, 0x00420002},
	"B:W18:BK1,K3", 3, EGDB_BLACK, EGDB_WIN, {0x00000005, 0x00020000, 0x00000005},
	"W:W18:BK1,K3", 3, EGDB_WHITE, EGDB_LOSS, {0x00000005, 0x00020000, 0x00000005},
	"B:WK3:BK1,15", 3, EGDB_BLACK, EGDB_WIN, {0x00004001, 0x00000004, 0x00000005},
	"W:WK3:BK1,15", 3, EGDB_WHITE, EGDB_LOSS, {0x00004001, 0x00000004, 0x00000005},
	"B:W21:BK2,9", 3, EGDB_BLACK, EGDB_WIN, {0x00000102, 0x00100000, 0x00000002},
	"W:W21:BK2,9", 3, EGDB_WHITE, EGDB_LOSS, {0x00000102, 0x00100000, 0x00000002},
	"B:WK2:B14,18", 3, EGDB_BLACK, EGDB_WIN, {0x00022000, 0x00000002, 0x00000002},
	"W:WK2:B14,18", 3, EGDB_WHITE, EGDB_LOSS, {0x00022000, 0x00000002, 0x00000002},
	"B:W24:B5,7", 3, EGDB_BLACK, EGDB_WIN, {0x00000050, 0x00800000, 0x00000000},
	"W:W24:B5,7", 3, EGDB_WHITE, EGDB_LOSS, {0x00000050, 0x00800000, 0x00000000},
	"B:WK2,K4:BK18,K23", 4, EGDB_BLACK, EGDB_DRAW, {0x00420000, 0x0000000a, 0x0042000a},
	"W:WK2,K4:BK18,K23", 4, EGDB_WHITE, EGDB_DRAW, {0x00420000, 0x0000000a, 0x0042000a},
	"B:WK10,18:BK1,K2", 4, EGDB_BLACK, EGDB_DRAW, {0x00000003, 0x00020200, 0x00000203},
	"W:WK10,18:BK1,K2", 4, EGDB_WHITE, EGDB_DRAW, {0x00000003, 0x00020200, 0x00000203},
	"B:W13,14:BK1,K4", 4, EGDB_BLACK, EGDB_WIN, {0x00000009, 0x00003000, 0x00000009},
	"W:W13,14:BK1,K4", 4, EGDB_WHITE, EGDB_DRAW, {0x00000009, 0x00003000, 0x00000009},
	"B:WK19,21:BK1,9", 4, EGDB_BLACK, EGDB_DRAW, {0x00000101, 0x00140000, 0x00040001},
	"W:WK19,21:BK1,9", 4, EGDB_WHITE, EGDB_DRAW, {0x00000101, 0x00140000, 0x00040001},
	"B:W15,24:BK4,5", 4, EGDB_BLACK, EGDB_DRAW, {0x00000018, 0x00804000, 0x00000008},
	"W:W15,24:BK4,5", 4, EGDB_WHITE, EGDB_DRAW, {0x00000018, 0x00804000, 0x00000008},
	"B:W17,26:B12,19", 4, EGDB_BLACK, EGDB_DRAW, {0x00040800, 0x02010000, 0x00000000},
	"W:W17,26:B12,19", 4, EGDB_WHITE, EGDB_DRAW, {0x00040800, 0x02010000, 0x00000000},
	"B:WK3:BK10,K20,K26", 4, EGDB_BLACK, EGDB_WIN, {0x02080200, 0x00000004, 0x02080204},
	"W:WK3:BK10,K20,K26", 4, EGDB_WHITE, EGDB_LOSS, {0x02080200, 0x00000004, 0x02080204},
	"B:W18:BK1,K3,K4", 4, EGDB_BLACK, EGDB_WIN, {0x0000000d, 0x00020000, 0x0000000d},
	"W:W18:BK1,K3,K4", 4, EGDB_WHITE, EGDB_LOSS, {0x0000000d, 0x00020000, 0x0000000d},
	"B:WK25:BK1,K2,15", 4, EGDB_BLACK, EGDB_WIN, {0x00004003, 0x01000000, 0x01000003},
	"W:WK25:BK1,K2,15", 4, EGDB_WHITE, EGDB_LOSS, {0x00004003, 0x01000000, 0x01000003},
	"B:W21:BK1,K5,9", 4, EGDB_BLACK, EGDB_WIN, {0x00000111, 0x00100000, 0x00000011},
	"W:W21:BK1,K5,9", 4, EGDB_WHITE, EGDB_LOSS, {0x00000111, 0x00100000, 0x00000011},
	"B:WK8:BK1,14,18", 4, EGDB_BLACK, EGDB_WIN, {0x00022001, 0x00000080, 0x00000081},
	"W:WK8:BK1,14,18", 4, EGDB_WHITE, EGDB_LOSS, {0x00022001, 0x00000080, 0x00000081},
	"B:W24:BK4,5,6", 4, EGDB_BLACK, EGDB_WIN, {0x00000038, 0x00800000, 0x00000008},
	"W:W24:BK4,5,6", 4, EGDB_WHITE, EGDB_LOSS, {0x00000038, 0x00800000, 0x00000008},
	"B:WK3:B6,12,19", 4, EGDB_BLACK, EGDB_WIN, {0x00040820, 0x00000004, 0x00000004},
	"W:WK3:B6,12,19", 4, EGDB_WHITE, EGDB_LOSS, {0x00040820, 0x00000004, 0x00000004},
	"B:W28:B6,14,23", 4, EGDB_BLACK, EGDB_WIN, {0x00402020, 0x08000000, 0x00000000},
	"W:W28:B6,14,23", 4, EGDB_WHITE, EGDB_LOSS, {0x00402020, 0x08000000, 0x00000000},
	"B:WK5,K11:BK10,K20,K26", 5, EGDB_BLACK, EGDB_WIN, {0x02080200, 0x00000410, 0x02080610},
	"W:WK5,K11:BK10,K20,K26", 5, EGDB_WHITE, EGDB_LOSS, {0x02080200, 0x00000410, 0x02080610},
	"B:W18,K19:BK1,K3,K4", 5, EGDB_BLACK, EGDB_WIN, {0x0000000d, 0x00060000, 0x0004000d},
	"W:W18,K19:BK1,K3,K4", 5, EGDB_WHITE, EGDB_LOSS, {0x0000000d, 0x00060000, 0x0004000d},
	"B:W13,14:BK1,K6,K7", 5, EGDB_BLACK, EGDB_WIN, {0x00000061, 0x00003000, 0x00000061},
	"W:W13,14:BK1,K6,K7", 5, EGDB_WHITE, EGDB_LOSS, {0x00000061, 0x00003000, 0x00000061},
	"B:WK3,K25:BK1,K2,15", 5, EGDB_BLACK, EGDB_WIN, {0x00004003, 0x01000004, 0x01000007},
	"W:WK3,K25:BK1,K2,15", 5, EGDB_WHITE, EGDB_LOSS, {0x00004003, 0x01000004, 0x01000007},
	"B:W21,K25:BK1,K6,9", 5, EGDB_BLACK, EGDB_WIN, {0x00000121, 0x01100000, 0x01000021},
	"W:W21,K25:BK1,K6,9", 5, EGDB_WHITE, EGDB_LOSS, {0x00000121, 0x01100000, 0x01000021},
	"B:W15,24:BK3,5,K23", 5, EGDB_BLACK, EGDB_WIN, {0x00400014, 0x00804000, 0x00400004},
	"W:W15,24:BK3,5,K23", 5, EGDB_WHITE, EGDB_LOSS, {0x00400014, 0x00804000, 0x00400004},
	"B:WK3,K5:BK1,14,18", 5, EGDB_BLACK, EGDB_WIN, {0x00022001, 0x00000014, 0x00000015},
	"W:WK3,K5:BK1,14,18", 5, EGDB_WHITE, EGDB_DRAW, {0x00022001, 0x00000014, 0x00000015},
	"B:W24,K26:B5,6,K8", 5, EGDB_BLACK, EGDB_WIN, {0x000000b0, 0x02800000, 0x02000080},
	"W:W24,K26:B5,6,K8", 5, EGDB_WHITE, EGDB_LOSS, {0x000000b0, 0x02800000, 0x02000080},
	"B:W17,26:B10,K16,19", 5, EGDB_BLACK, EGDB_WIN, {0x00048200, 0x02010000, 0x00008000},
	"W:W17,26:B10,K16,19", 5, EGDB_WHITE, EGDB_LOSS, {0x00048200, 0x02010000, 0x00008000},
	"B:WK13,K20:B6,12,19", 5, EGDB_BLACK, EGDB_DRAW, {0x00040820, 0x00081000, 0x00081000},
	"W:WK13,K20:B6,12,19", 5, EGDB_WHITE, EGDB_DRAW, {0x00040820, 0x00081000, 0x00081000},
	"B:WK21,28:B7,14,23", 5, EGDB_BLACK, EGDB_WIN, {0x00402040, 0x08100000, 0x00100000},
	"W:WK21,28:B7,14,23", 5, EGDB_WHITE, EGDB_LOSS, {0x00402040, 0x08100000, 0x00100000},
	"B:W21,29:B13,16,24", 5, EGDB_BLACK, EGDB_WIN, {0x00809000, 0x10100000, 0x00000000},
	"W:W21,29:B13,16,24", 5, EGDB_WHITE, EGDB_LOSS, {0x00809000, 0x10100000, 0x00000000},
	"B:WK16:BK2,K13,K15,K28", 5, EGDB_BLACK, EGDB_WIN, {0x08005002, 0x00008000, 0x0800d002},
	"W:WK16:BK2,K13,K15,K28", 5, EGDB_WHITE, EGDB_LOSS, {0x08005002, 0x00008000, 0x0800d002},
	"B:W18:BK2,K3,K5,K6", 5, EGDB_BLACK, EGDB_WIN, {0x00000036, 0x00020000, 0x00000036},
	"W:W18:BK2,K3,K5,K6", 5, EGDB_WHITE, EGDB_LOSS, {0x00000036, 0x00020000, 0x00000036},
	"B:WK2:BK1,K3,K5,15", 5, EGDB_BLACK, EGDB_WIN, {0x00004015, 0x00000002, 0x00000017},
	"W:WK2:BK1,K3,K5,15", 5, EGDB_WHITE, EGDB_LOSS, {0x00004015, 0x00000002, 0x00000017},
	"B:W21:BK2,K3,K6,9", 5, EGDB_BLACK, EGDB_WIN, {0x00000126, 0x00100000, 0x00000026},
	"W:W21:BK2,K3,K6,9", 5, EGDB_WHITE, EGDB_LOSS, {0x00000126, 0x00100000, 0x00000026},
	"B:WK16:BK1,K4,14,18", 5, EGDB_BLACK, EGDB_WIN, {0x00022009, 0x00008000, 0x00008009},
	"W:WK16:BK1,K4,14,18", 5, EGDB_WHITE, EGDB_LOSS, {0x00022009, 0x00008000, 0x00008009},
	"B:W24:B5,6,K7,K11", 5, EGDB_BLACK, EGDB_WIN, {0x00000470, 0x00800000, 0x00000440},
	"W:W24:B5,6,K7,K11", 5, EGDB_WHITE, EGDB_LOSS, {0x00000470, 0x00800000, 0x00000440},
	"B:WK31:BK5,6,12,19", 5, EGDB_BLACK, EGDB_WIN, {0x00040830, 0x40000000, 0x40000010},
	"W:WK31:BK5,6,12,19", 5, EGDB_WHITE, EGDB_LOSS, {0x00040830, 0x40000000, 0x40000010},
	"B:W28:BK1,6,14,23", 5, EGDB_BLACK, EGDB_WIN, {0x00402021, 0x08000000, 0x00000001},
	"W:W28:BK1,6,14,23", 5, EGDB_WHITE, EGDB_LOSS, {0x00402021, 0x08000000, 0x00000001},
	"B:WK29:B6,7,13,16", 5, EGDB_BLACK, EGDB_WIN, {0x00009060, 0x10000000, 0x10000000},
	"W:WK29:B6,7,13,16", 5, EGDB_WHITE, EGDB_LOSS, {0x00009060, 0x10000000, 0x10000000},
	"B:W32:B10,16,19,23", 5, EGDB_BLACK, EGDB_WIN, {0x00448200, 0x80000000, 0x00000000},
	"W:W32:B10,16,19,23", 5, EGDB_WHITE, EGDB_LOSS, {0x00448200, 0x80000000, 0x00000000},
	"B:WK12,K13,K27:BK10,K20,K26", 6, EGDB_BLACK, EGDB_DRAW, {0x02080200, 0x04001800, 0x06081a00},
	"W:WK12,K13,K27:BK10,K20,K26", 6, EGDB_WHITE, EGDB_DRAW, {0x02080200, 0x04001800, 0x06081a00},
	"B:WK7,K10,18:BK1,K3,K4", 6, EGDB_BLACK, EGDB_WIN, {0x0000000d, 0x00020240, 0x0000024d},
	"W:WK7,K10,18:BK1,K3,K4", 6, EGDB_WHITE, EGDB_DRAW, {0x0000000d, 0x00020240, 0x0000024d},
	"B:W13,14,K15:BK1,K2,K4", 6, EGDB_BLACK, EGDB_WIN, {0x0000000b, 0x00007000, 0x0000400b},
	"W:W13,14,K15:BK1,K2,K4", 6, EGDB_WHITE, EGDB_LOSS, {0x0000000b, 0x00007000, 0x0000400b},
	"B:W10,18,25:BK4,K12,K17", 6, EGDB_BLACK, EGDB_WIN, {0x00010808, 0x01020200, 0x00010808},
	"W:W10,18,25:BK4,K12,K17", 6, EGDB_WHITE, EGDB_LOSS, {0x00010808, 0x01020200, 0x00010808},
	"B:WK10,K17,21:BK2,K4,9", 6, EGDB_BLACK, EGDB_DRAW, {0x0000010a, 0x00110200, 0x0001020a},
	"W:WK10,K17,21:BK2,K4,9", 6, EGDB_WHITE, EGDB_DRAW, {0x0000010a, 0x00110200, 0x0001020a},
	"B:WK1,15,24:B5,K9,K13", 6, EGDB_BLACK, EGDB_DRAW, {0x00001110, 0x00804001, 0x00001101},
	"W:WK1,15,24:B5,K9,K13", 6, EGDB_WHITE, EGDB_DRAW, {0x00001110, 0x00804001, 0x00001101},
	"B:W11,21,28:BK5,K10,22", 6, EGDB_BLACK, EGDB_WIN, {0x00200210, 0x08100400, 0x00000210},
	"W:W11,21,28:BK5,K10,22", 6, EGDB_WHITE, EGDB_LOSS, {0x00200210, 0x08100400, 0x00000210},
	"B:W17,K22,26:BK6,11,19", 6, EGDB_BLACK, EGDB_DRAW, {0x00040420, 0x02210000, 0x00200020},
	"W:W17,K22,26:BK6,11,19", 6, EGDB_WHITE, EGDB_DRAW, {0x00040420, 0x02210000, 0x00200020},
	"B:W13,18,21:BK1,24,25", 6, EGDB_BLACK, EGDB_DRAW, {0x01800001, 0x00121000, 0x00000001},
	"W:W13,18,21:BK1,24,25", 6, EGDB_WHITE, EGDB_DRAW, {0x01800001, 0x00121000, 0x00000001},
	"B:W18,21,30:B6,10,27", 6, EGDB_BLACK, EGDB_DRAW, {0x04000220, 0x20120000, 0x00000000},
	"W:W18,21,30:B6,10,27", 6, EGDB_WHITE, EGDB_DRAW, {0x04000220, 0x20120000, 0x00000000},
	"B:WK25,K29:BK3,K13,K15,K28", 6, EGDB_BLACK, EGDB_WIN, {0x08005004, 0x11000000, 0x19005004},
	"W:WK25,K29:BK3,K13,K15,K28", 6, EGDB_WHITE, EGDB_LOSS, {0x08005004, 0x11000000, 0x19005004},
	"B:W18,K20:BK2,K3,K4,K6", 6, EGDB_BLACK, EGDB_WIN, {0x0000002e, 0x000a0000, 0x0008002e},
	"W:W18,K20:BK2,K3,K4,K6", 6, EGDB_WHITE, EGDB_LOSS, {0x0000002e, 0x000a0000, 0x0008002e},
	"B:W13,14:BK1,K2,K5,K6", 6, EGDB_BLACK, EGDB_WIN, {0x00000033, 0x00003000, 0x00000033},
	"W:W13,14:BK1,K2,K5,K6", 6, EGDB_WHITE, EGDB_LOSS, {0x00000033, 0x00003000, 0x00000033},
	"B:WK20,K26:BK3,K4,K5,15", 6, EGDB_BLACK, EGDB_WIN, {0x0000401c, 0x02080000, 0x0208001c},
	"W:WK20,K26:BK3,K4,K5,15", 6, EGDB_WHITE, EGDB_LOSS, {0x0000401c, 0x02080000, 0x0208001c},
	"B:WK16,21:BK2,K4,K8,9", 6, EGDB_BLACK, EGDB_WIN, {0x0000018a, 0x00108000, 0x0000808a},
	"W:WK16,21:BK2,K4,K8,9", 6, EGDB_WHITE, EGDB_LOSS, {0x0000018a, 0x00108000, 0x0000808a},
	"B:W15,24:BK6,7,K17,K23", 6, EGDB_BLACK, EGDB_WIN, {0x00410060, 0x00804000, 0x00410020},
	"W:W15,24:BK6,7,K17,K23", 6, EGDB_WHITE, EGDB_LOSS, {0x00410060, 0x00804000, 0x00410020},
	"B:WK9,K26:BK1,K2,14,18", 6, EGDB_BLACK, EGDB_WIN, {0x00022003, 0x02000100, 0x02000103},
	"W:WK9,K26:BK1,K2,14,18", 6, EGDB_WHITE, EGDB_LOSS, {0x00022003, 0x02000100, 0x02000103},
	"B:WK1,24:B5,6,K10,K14", 6, EGDB_BLACK, EGDB_WIN, {0x00002230, 0x00800001, 0x00002201},
	"W:WK1,24:B5,6,K10,K14", 6, EGDB_WHITE, EGDB_LOSS, {0x00002230, 0x00800001, 0x00002201},
	"B:W16,26:BK5,18,19,K29", 6, EGDB_BLACK, EGDB_WIN, {0x10060010, 0x02008000, 0x10000010},
	"W:W16,26:BK5,18,19,K29", 6, EGDB_WHITE, EGDB_LOSS, {0x10060010, 0x02008000, 0x10000010},
	"B:WK5,K31:BK2,6,12,19", 6, EGDB_BLACK, EGDB_WIN, {0x00040822, 0x40000010, 0x40000012},
	"W:WK5,K31:BK2,6,12,19", 6, EGDB_WHITE, EGDB_LOSS, {0x00040822, 0x40000010, 0x40000012},
	"B:W28,K31:BK7,8,14,23", 6, EGDB_BLACK, EGDB_WIN, {0x004020c0, 0x48000000, 0x40000040},
	"W:W28,K31:BK7,8,14,23", 6, EGDB_WHITE, EGDB_LOSS, {0x004020c0, 0x48000000, 0x40000040},
	"B:W21,29:BK10,15,18,24", 6, EGDB_BLACK, EGDB_WIN, {0x00824200, 0x10100000, 0x00000200},
	"W:W21,29:BK10,15,18,24", 6, EGDB_WHITE, EGDB_LOSS, {0x00824200, 0x10100000, 0x00000200},
	"B:WK5,K29:B6,7,13,16", 6, EGDB_BLACK, EGDB_WIN, {0x00009060, 0x10000010, 0x10000010},
	"W:WK5,K29:B6,7,13,16", 6, EGDB_WHITE, EGDB_LOSS, {0x00009060, 0x10000010, 0x10000010},
	"B:WK9,32:B8,16,19,23", 6, EGDB_BLACK, EGDB_WIN, {0x00448080, 0x80000100, 0x00000100},
	"W:WK9,32:B8,16,19,23", 6, EGDB_WHITE, EGDB_LOSS, {0x00448080, 0x80000100, 0x00000100},
	"B:W5,11:B3,9,16,27", 6, EGDB_BLACK, EGDB_WIN, {0x04008104, 0x00000410, 0x00000000},
	"W:W5,11:B3,9,16,27", 6, EGDB_WHITE, EGDB_LOSS, {0x04008104, 0x00000410, 0x00000000},
	"B:WK2:BK1,K3,K8,K18,K29", 6, EGDB_BLACK, EGDB_WIN, {0x10020085, 0x00000002, 0x10020087},
	"W:WK2:BK1,K3,K8,K18,K29", 6, EGDB_WHITE, EGDB_LOSS, {0x10020085, 0x00000002, 0x10020087},
	"B:W18:BK1,K2,K6,K7,K8", 6, EGDB_BLACK, EGDB_WIN, {0x000000e3, 0x00020000, 0x000000e3},
	"W:W18:BK1,K2,K6,K7,K8", 6, EGDB_WHITE, EGDB_LOSS, {0x000000e3, 0x00020000, 0x000000e3},
	"B:WK20:BK2,K3,K4,K6,15", 6, EGDB_BLACK, EGDB_WIN, {0x0000402e, 0x00080000, 0x0008002e},
	"W:WK20:BK2,K3,K4,K6,15", 6, EGDB_WHITE, EGDB_LOSS, {0x0000402e, 0x00080000, 0x0008002e},
	"B:W21:BK5,K6,K7,9,K12", 6, EGDB_BLACK, EGDB_WIN, {0x00000970, 0x00100000, 0x00000870},
	"W:W21:BK5,K6,K7,9,K12", 6, EGDB_WHITE, EGDB_LOSS, {0x00000970, 0x00100000, 0x00000870},
	"B:WK13:BK1,K2,K4,14,18", 6, EGDB_BLACK, EGDB_WIN, {0x0002200b, 0x00001000, 0x0000100b},
	"W:WK13:BK1,K2,K4,14,18", 6, EGDB_WHITE, EGDB_LOSS, {0x0002200b, 0x00001000, 0x0000100b},
	"B:W24:B5,6,K15,K17,K18", 6, EGDB_BLACK, EGDB_WIN, {0x00034030, 0x00800000, 0x00034000},
	"W:W24:B5,6,K15,K17,K18", 6, EGDB_WHITE, EGDB_LOSS, {0x00034030, 0x00800000, 0x00034000},
	"B:WK26:B6,K9,12,K13,19", 6, EGDB_BLACK, EGDB_WIN, {0x00041920, 0x02000000, 0x02001100},
	"W:WK26:B6,K9,12,K13,19", 6, EGDB_WHITE, EGDB_LOSS, {0x00041920, 0x02000000, 0x02001100},
	"B:W28:B5,K9,K11,14,23", 6, EGDB_BLACK, EGDB_WIN, {0x00402510, 0x08000000, 0x00000500},
	"W:W28:B5,K9,K11,14,23", 6, EGDB_WHITE, EGDB_LOSS, {0x00402510, 0x08000000, 0x00000500},
	"B:WK30:B5,8,K10,13,16", 6, EGDB_BLACK, EGDB_WIN, {0x00009290, 0x20000000, 0x20000200},
	"W:WK30:B5,8,K10,13,16", 6, EGDB_WHITE, EGDB_LOSS, {0x00009290, 0x20000000, 0x20000200},
	"B:W32:B8,K9,16,19,23", 6, EGDB_BLACK, EGDB_WIN, {0x00448180, 0x80000000, 0x00000100},
	"W:W32:B8,K9,16,19,23", 6, EGDB_WHITE, EGDB_LOSS, {0x00448180, 0x80000000, 0x00000100},
	"B:WK27:B1,5,13,14,28", 6, EGDB_BLACK, EGDB_WIN, {0x08003011, 0x04000000, 0x04000000},
	"W:WK27:B1,5,13,14,28", 6, EGDB_WHITE, EGDB_LOSS, {0x08003011, 0x04000000, 0x04000000},
	"B:W10:B3,5,11,17,26", 6, EGDB_BLACK, EGDB_WIN, {0x02010414, 0x00000200, 0x00000000},
	"W:W10:B3,5,11,17,26", 6, EGDB_WHITE, EGDB_LOSS, {0x02010414, 0x00000200, 0x00000000},
	"B:WK17,K26,K30:BK4,K9,K16,K28", 7, EGDB_BLACK, EGDB_WIN, {0x08008108, 0x22010000, 0x2a018108},
	"W:WK17,K26,K30:BK4,K9,K16,K28", 7, EGDB_WHITE, EGDB_LOSS, {0x08008108, 0x22010000, 0x2a018108},
	"B:W18,K22,K31:BK1,K6,K8,K10", 7, EGDB_BLACK, EGDB_WIN, {0x000002a1, 0x40220000, 0x402002a1},
	"W:W18,K22,K31:BK1,K6,K8,K10", 7, EGDB_WHITE, EGDB_LOSS, {0x000002a1, 0x40220000, 0x402002a1},
	"B:WK3,13,14:BK1,K5,K15,K19", 7, EGDB_BLACK, EGDB_WIN, {0x00044011, 0x00003004, 0x00044015},
	"W:WK3,13,14:BK1,K5,K15,K19", 7, EGDB_WHITE, EGDB_LOSS, {0x00044011, 0x00003004, 0x00044015},
	"B:W10,18,24:BK1,K4,K21,K32", 7, EGDB_BLACK, EGDB_WIN, {0x80100009, 0x00820200, 0x80100009},
	"W:W10,18,24:BK1,K4,K21,K32", 7, EGDB_WHITE, EGDB_LOSS, {0x80100009, 0x00820200, 0x80100009},
	"B:WK26,K29,K32:BK5,K6,K8,15", 7, EGDB_BLACK, EGDB_WIN, {0x000040b0, 0x92000000, 0x920000b0},
	"W:WK26,K29,K32:BK5,K6,K8,15", 7, EGDB_WHITE, EGDB_LOSS, {0x000040b0, 0x92000000, 0x920000b0},
	"B:WK4,K19,21:BK2,9,K13,K18", 7, EGDB_BLACK, EGDB_WIN, {0x00021102, 0x00140008, 0x0006100a},
	"W:WK4,K19,21:BK2,9,K13,K18", 7, EGDB_WHITE, EGDB_LOSS, {0x00021102, 0x00140008, 0x0006100a},
	"B:WK6,15,24:BK4,8,K23,K32", 7, EGDB_BLACK, EGDB_WIN, {0x80400088, 0x00804020, 0x80400028},
	"W:WK6,15,24:BK4,8,K23,K32", 7, EGDB_WHITE, EGDB_LOSS, {0x80400088, 0x00804020, 0x80400028},
	"B:W12,22,27:BK3,9,K13,K14", 7, EGDB_BLACK, EGDB_WIN, {0x00003104, 0x04200800, 0x00003004},
	"W:W12,22,27:BK3,9,K13,K14", 7, EGDB_WHITE, EGDB_LOSS, {0x00003104, 0x04200800, 0x00003004},
	"B:WK4,K13,K25:BK11,K12,14,18", 7, EGDB_BLACK, EGDB_WIN, {0x00022c00, 0x01001008, 0x01001c08},
	"W:WK4,K13,K25:BK11,K12,14,18", 7, EGDB_WHITE, EGDB_LOSS, {0x00022c00, 0x01001008, 0x01001c08},
	"B:WK18,24,K29:BK6,7,8,K32", 7, EGDB_BLACK, EGDB_WIN, {0x800000e0, 0x10820000, 0x90020020},
	"W:WK18,24,K29:BK6,7,8,K32", 7, EGDB_WHITE, EGDB_LOSS, {0x800000e0, 0x10820000, 0x90020020},
	"B:W17,26,K32:B6,K8,K10,21", 7, EGDB_BLACK, EGDB_WIN, {0x001002a0, 0x82010000, 0x80000280},
	"W:W17,26,K32:B6,K8,K10,21", 7, EGDB_WHITE, EGDB_LOSS, {0x001002a0, 0x82010000, 0x80000280},
	"B:W15,20,21:BK1,12,14,K24", 7, EGDB_BLACK, EGDB_WIN, {0x00802801, 0x00184000, 0x00800001},
	"W:W15,20,21:BK1,12,14,K24", 7, EGDB_WHITE, EGDB_LOSS, {0x00802801, 0x00184000, 0x00800001},
	"B:WK9,K25,K27:B10,12,19,K20", 7, EGDB_BLACK, EGDB_DRAW, {0x000c0a00, 0x05000100, 0x05080100},
	"W:WK9,K25,K27:B10,12,19,K20", 7, EGDB_WHITE, EGDB_DRAW, {0x000c0a00, 0x05000100, 0x05080100},
	"B:WK2,K8,28:B12,15,K19,23", 7, EGDB_BLACK, EGDB_WIN, {0x00444800, 0x08000082, 0x00040082},
	"W:WK2,K8,28:B12,15,K19,23", 7, EGDB_WHITE, EGDB_LOSS, {0x00444800, 0x08000082, 0x00040082},
	"B:WK2,21,29:BK1,11,19,26", 7, EGDB_BLACK, EGDB_WIN, {0x02040401, 0x10100002, 0x00000003},
	"W:WK2,21,29:BK1,11,19,26", 7, EGDB_WHITE, EGDB_LOSS, {0x02040401, 0x10100002, 0x00000003},
	"B:W17,21,29:B9,19,22,K27", 7, EGDB_BLACK, EGDB_WIN, {0x04240100, 0x10110000, 0x04000000},
	"W:W17,21,29:B9,19,22,K27", 7, EGDB_WHITE, EGDB_LOSS, {0x04240100, 0x10110000, 0x04000000},
	"B:WK22,K23,K27:B5,10,13,16", 7, EGDB_BLACK, EGDB_LOSS, {0x00009210, 0x04600000, 0x04600000},
	"W:WK22,K23,K27:B5,10,13,16", 7, EGDB_WHITE, EGDB_WIN, {0x00009210, 0x04600000, 0x04600000},
	"B:WK7,K14,32:B5,16,20,23", 7, EGDB_BLACK, EGDB_WIN, {0x00488010, 0x80002040, 0x00002040},
	"W:WK7,K14,32:B5,16,20,23", 7, EGDB_WHITE, EGDB_DRAW, {0x00488010, 0x80002040, 0x00002040},
	"B:W5,10,K23:B3,8,13,15", 7, EGDB_BLACK, EGDB_WIN, {0x00005084, 0x00400210, 0x00400000},
	"W:W5,10,K23:B3,8,13,15", 7, EGDB_WHITE, EGDB_DRAW, {0x00005084, 0x00400210, 0x00400000},
	"B:W5,10,32:B4,15,24,26", 7, EGDB_BLACK, EGDB_WIN, {0x02804008, 0x80000210, 0x00000000},
	"W:W5,10,32:B4,15,24,26", 7, EGDB_WHITE, EGDB_LOSS, {0x02804008, 0x80000210, 0x00000000},
	"B:WK4,K20:BK6,K7,K10,K18,K29", 7, EGDB_BLACK, EGDB_WIN, {0x10020260, 0x00080008, 0x100a0268},
	"W:WK4,K20:BK6,K7,K10,K18,K29", 7, EGDB_WHITE, EGDB_LOSS, {0x10020260, 0x00080008, 0x100a0268},
	"B:W18,K20:BK4,K5,K7,K10,K13", 7, EGDB_BLACK, EGDB_WIN, {0x00001258, 0x000a0000, 0x00081258},
	"W:W18,K20:BK4,K5,K7,K10,K13", 7, EGDB_WHITE, EGDB_LOSS, {0x00001258, 0x000a0000, 0x00081258},
	"B:W13,14:BK3,K5,K7,K8,K24", 7, EGDB_BLACK, EGDB_WIN, {0x008000d4, 0x00003000, 0x008000d4},
	"W:W13,14:BK3,K5,K7,K8,K24", 7, EGDB_WHITE, EGDB_LOSS, {0x008000d4, 0x00003000, 0x008000d4},
	"B:WK22,K31:BK1,K6,K8,K10,15", 7, EGDB_BLACK, EGDB_WIN, {0x000042a1, 0x40200000, 0x402002a1},
	"W:WK22,K31:BK1,K6,K8,K10,15", 7, EGDB_WHITE, EGDB_LOSS, {0x000042a1, 0x40200000, 0x402002a1},
	"B:WK7,21:B9,K12,K19,K20,K25", 7, EGDB_BLACK, EGDB_WIN, {0x010c0900, 0x00100040, 0x010c0840},
	"W:WK7,21:B9,K12,K19,K20,K25", 7, EGDB_WHITE, EGDB_LOSS, {0x010c0900, 0x00100040, 0x010c0840},
	"B:W15,24:BK4,12,K25,K29,K31", 7, EGDB_BLACK, EGDB_WIN, {0x51000808, 0x00804000, 0x51000008},
	"W:W15,24:BK4,12,K25,K29,K31", 7, EGDB_WHITE, EGDB_LOSS, {0x51000808, 0x00804000, 0x51000008},
	"B:WK8,K12:BK3,K7,14,K15,18", 7, EGDB_BLACK, EGDB_WIN, {0x00026044, 0x00000880, 0x000048c4},
	"W:WK8,K12:BK3,K7,14,K15,18", 7, EGDB_WHITE, EGDB_LOSS, {0x00026044, 0x00000880, 0x000048c4},
	"B:WK7,24:BK4,5,8,K23,K32", 7, EGDB_BLACK, EGDB_WIN, {0x80400098, 0x00800040, 0x80400048},
	"W:WK7,24:BK4,5,8,K23,K32", 7, EGDB_WHITE, EGDB_LOSS, {0x80400098, 0x00800040, 0x80400048},
	"B:W17,26:BK3,6,K8,K15,21", 7, EGDB_BLACK, EGDB_WIN, {0x001040a4, 0x02010000, 0x00004084},
	"W:W17,26:BK3,6,K8,K15,21", 7, EGDB_WHITE, EGDB_LOSS, {0x001040a4, 0x02010000, 0x00004084},
	"B:WK1,K25:B8,K10,13,K14,19", 7, EGDB_BLACK, EGDB_WIN, {0x00043280, 0x01000001, 0x01002201},
	"W:WK1,K25:B8,K10,13,K14,19", 7, EGDB_WHITE, EGDB_LOSS, {0x00043280, 0x01000001, 0x01002201},
	"B:W28,K31:BK4,K14,19,20,23", 7, EGDB_BLACK, EGDB_WIN, {0x004c2008, 0x48000000, 0x40002008},
	"W:W28,K31:BK4,K14,19,20,23", 7, EGDB_WHITE, EGDB_LOSS, {0x004c2008, 0x48000000, 0x40002008},
	"B:W21,29:BK1,7,19,K22,26", 7, EGDB_BLACK, EGDB_WIN, {0x02240041, 0x10100000, 0x00200001},
	"W:W21,29:BK1,7,19,K22,26", 7, EGDB_WHITE, EGDB_LOSS, {0x02240041, 0x10100000, 0x00200001},
	"B:WK8,K27:B5,10,13,16,K19", 7, EGDB_BLACK, EGDB_WIN, {0x00049210, 0x04000080, 0x04040080},
	"W:WK8,K27:B5,10,13,16,K19", 7, EGDB_WHITE, EGDB_LOSS, {0x00049210, 0x04000080, 0x04040080},
	"B:WK12,32:BK11,14,15,21,23", 7, EGDB_BLACK, EGDB_WIN, {0x00506400, 0x80000800, 0x00000c00},
	"W:WK12,32:BK11,14,15,21,23", 7, EGDB_WHITE, EGDB_LOSS, {0x00506400, 0x80000800, 0x00000c00},
	"B:W5,10:B3,8,13,15,K23", 7, EGDB_BLACK, EGDB_WIN, {0x00405084, 0x00000210, 0x00400000},
	"W:W5,10:B3,8,13,15,K23", 7, EGDB_WHITE, EGDB_LOSS, {0x00405084, 0x00000210, 0x00400000},
	"B:WK21,K30:B2,9,13,14,28", 7, EGDB_BLACK, EGDB_WIN, {0x08003102, 0x20100000, 0x20100000},
	"W:WK21,K30:B2,9,13,14,28", 7, EGDB_WHITE, EGDB_LOSS, {0x08003102, 0x20100000, 0x20100000},
	"B:W9,K21:B3,12,13,18,26", 7, EGDB_BLACK, EGDB_WIN, {0x02021804, 0x00100100, 0x00100000},
	"W:W9,K21:B3,12,13,18,26", 7, EGDB_WHITE, EGDB_LOSS, {0x02021804, 0x00100100, 0x00100000},
	"B:W7,25:B4,9,16,23,24", 7, EGDB_BLACK, EGDB_WIN, {0x00c08108, 0x01000040, 0x00000000},
	"W:W7,25:B4,9,16,23,24", 7, EGDB_WHITE, EGDB_LOSS, {0x00c08108, 0x01000040, 0x00000000},
	"B:WK4,K6,K10,K31:BK5,K16,K17,K28", 8, EGDB_BLACK, EGDB_DRAW, {0x08018010, 0x40000228, 0x48018238},
	"W:WK4,K6,K10,K31:BK5,K16,K17,K28", 8, EGDB_WHITE, EGDB_DRAW, {0x08018010, 0x40000228, 0x48018238},
	"B:WK2,18,K22,K30:BK11,K15,K16,K19", 8, EGDB_BLACK, EGDB_DRAW, {0x0004c400, 0x20220002, 0x2024c402},
	"W:WK2,18,K22,K30:BK11,K15,K16,K19", 8, EGDB_WHITE, EGDB_DRAW, {0x0004c400, 0x20220002, 0x2024c402},
	"B:WK4,K10,12,32:BK1,K2,K22,K23", 8, EGDB_BLACK, EGDB_WIN, {0x00600003, 0x80000a08, 0x0060020b},
	"W:WK4,K10,12,32:BK1,K2,K22,K23", 8, EGDB_WHITE, EGDB_DRAW, {0x00600003, 0x80000a08, 0x0060020b},
	"B:W10,17,29,K30:BK1,K12,K24,K32", 8, EGDB_BLACK, EGDB_WIN, {0x80800801, 0x30010200, 0xa0800801},
	"W:W10,17,29,K30:BK1,K12,K24,K32", 8, EGDB_WHITE, EGDB_DRAW, {0x80800801, 0x30010200, 0xa0800801},
	"B:W9,11,13,15:BK2,K26,K31,K32", 8, EGDB_BLACK, EGDB_DRAW, {0xc2000002, 0x00005500, 0xc2000002},
	"W:W9,11,13,15:BK2,K26,K31,K32", 8, EGDB_WHITE, EGDB_DRAW, {0xc2000002, 0x00005500, 0xc2000002},
	"B:WK2,K3,K4,21:BK1,16,K19,K28", 8, EGDB_BLACK, EGDB_DRAW, {0x08048001, 0x0010000e, 0x0804000f},
	"W:WK2,K3,K4,21:BK1,16,K19,K28", 8, EGDB_WHITE, EGDB_DRAW, {0x08048001, 0x0010000e, 0x0804000f},
	"B:WK4,15,23,K25:BK9,K13,14,K17", 8, EGDB_BLACK, EGDB_DRAW, {0x00013100, 0x01404008, 0x01011108},
	"W:WK4,15,23,K25:BK9,K13,14,K17", 8, EGDB_WHITE, EGDB_DRAW, {0x00013100, 0x01404008, 0x01011108},
	"B:W12,21,K22,26:B6,K16,K24,K29", 8, EGDB_BLACK, EGDB_WIN, {0x10808020, 0x02300800, 0x10a08000},
	"W:W12,21,K22,26:B6,K16,K24,K29", 8, EGDB_WHITE, EGDB_DRAW, {0x10808020, 0x02300800, 0x10a08000},
	"B:W10,11,27,29:BK1,K2,K3,20", 8, EGDB_BLACK, EGDB_WIN, {0x00080007, 0x14000600, 0x00000007},
	"W:W10,11,27,29:BK1,K2,K3,20", 8, EGDB_WHITE, EGDB_LOSS, {0x00080007, 0x14000600, 0x00000007},
	"B:W17,K22,24,K25:BK8,12,27,K31", 8, EGDB_BLACK, EGDB_DRAW, {0x44000880, 0x01a10000, 0x41200080},
	"W:W17,K22,24,K25:BK8,12,27,K31", 8, EGDB_WHITE, EGDB_DRAW, {0x44000880, 0x01a10000, 0x41200080},
	"B:W14,16,K19,25:BK7,12,23,K26", 8, EGDB_BLACK, EGDB_WIN, {0x02400840, 0x0104a000, 0x02040040},
	"W:W14,16,K19,25:BK7,12,23,K26", 8, EGDB_WHITE, EGDB_DRAW, {0x02400840, 0x0104a000, 0x02040040},
	"B:W12,17,23,29:B10,K11,K16,28", 8, EGDB_BLACK, EGDB_WIN, {0x08008600, 0x10410800, 0x00008400},
	"W:W12,17,23,29:B10,K11,K16,28", 8, EGDB_WHITE, EGDB_LOSS, {0x08008600, 0x10410800, 0x00008400},
	"B:W17,18,K20,24:B9,23,27,K29", 8, EGDB_BLACK, EGDB_DRAW, {0x14400100, 0x008b0000, 0x10080000},
	"W:W17,18,K20,24:B9,23,27,K29", 8, EGDB_WHITE, EGDB_WIN, {0x14400100, 0x008b0000, 0x10080000},
	"B:W16,20,29,30:B10,13,14,K31", 8, EGDB_BLACK, EGDB_DRAW, {0x40003200, 0x30088000, 0x40000000},
	"W:W16,20,29,30:B10,13,14,K31", 8, EGDB_WHITE, EGDB_DRAW, {0x40003200, 0x30088000, 0x40000000},
	"B:W5,10,11,14:B4,17,23,24", 8, EGDB_BLACK, EGDB_DRAW, {0x00c10008, 0x00002610, 0x00000000},
	"W:W5,10,11,14:B4,17,23,24", 8, EGDB_WHITE, EGDB_DRAW, {0x00c10008, 0x00002610, 0x00000000},
	"B:WK8,K27,K30:BK17,K18,K20,K22,K29", 8, EGDB_BLACK, EGDB_WIN, {0x102b0000, 0x24000080, 0x342b0080},
	"W:WK8,K27,K30:BK17,K18,K20,K22,K29", 8, EGDB_WHITE, EGDB_LOSS, {0x102b0000, 0x24000080, 0x342b0080},
	"B:WK9,18,K30:BK1,K11,K20,K27,K28", 8, EGDB_BLACK, EGDB_WIN, {0x0c080401, 0x20020100, 0x2c080501},
	"W:WK9,18,K30:BK1,K11,K20,K27,K28", 8, EGDB_WHITE, EGDB_LOSS, {0x0c080401, 0x20020100, 0x2c080501},
	"B:WK5,12,31:BK4,K10,K21,K24,K28", 8, EGDB_BLACK, EGDB_WIN, {0x08900208, 0x40000810, 0x08900218},
	"W:WK5,12,31:BK4,K10,K21,K24,K28", 8, EGDB_WHITE, EGDB_LOSS, {0x08900208, 0x40000810, 0x08900218},
	"B:W10,13,29:BK17,K18,K20,K26,K27", 8, EGDB_BLACK, EGDB_WIN, {0x060b0000, 0x10001200, 0x060b0000},
	"W:W10,13,29:BK17,K18,K20,K26,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x060b0000, 0x10001200, 0x060b0000},
	"B:WK1,K2,K3:B16,K20,K21,K25,K26", 8, EGDB_BLACK, EGDB_WIN, {0x03188000, 0x00000007, 0x03180007},
	"W:WK1,K2,K3:B16,K20,K21,K25,K26", 8, EGDB_WHITE, EGDB_LOSS, {0x03188000, 0x00000007, 0x03180007},
	"B:WK2,K3,21:BK1,K4,K5,14,K18", 8, EGDB_BLACK, EGDB_WIN, {0x00022019, 0x00100006, 0x0002001f},
	"W:WK2,K3,21:BK1,K4,K5,14,K18", 8, EGDB_WHITE, EGDB_LOSS, {0x00022019, 0x00100006, 0x0002001f},
	"B:W14,17,K20:BK6,K12,K25,26,K29", 8, EGDB_BLACK, EGDB_WIN, {0x13000820, 0x00092000, 0x11080820},
	"W:W14,17,K20:BK6,K12,K25,26,K29", 8, EGDB_WHITE, EGDB_LOSS, {0x13000820, 0x00092000, 0x11080820},
	"B:W11,19,26:BK1,K2,K9,20,K27", 8, EGDB_BLACK, EGDB_WIN, {0x04080103, 0x02040400, 0x04000103},
	"W:W11,19,26:BK1,K2,K9,20,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x04080103, 0x02040400, 0x04000103},
	"B:WK5,K8,K21:BK10,K14,16,18,K27", 8, EGDB_BLACK, EGDB_WIN, {0x0402a200, 0x00100090, 0x04102290},
	"W:WK5,K8,K21:BK10,K14,16,18,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x0402a200, 0x00100090, 0x04102290},
	"B:WK4,24,K25:BK9,10,13,K15,K17", 8, EGDB_BLACK, EGDB_WIN, {0x00015300, 0x01800008, 0x01014108},
	"W:WK4,24,K25:BK9,10,13,K15,K17", 8, EGDB_WHITE, EGDB_LOSS, {0x00015300, 0x01800008, 0x01014108},
	"B:W17,24,K28:BK7,12,27,K29,K31", 8, EGDB_BLACK, EGDB_WIN, {0x54000840, 0x08810000, 0x58000040},
	"W:W17,24,K28:BK7,12,27,K29,K31", 8, EGDB_WHITE, EGDB_LOSS, {0x54000840, 0x08810000, 0x58000040},
	"B:W13,17,21:BK2,K24,25,K26,28", 8, EGDB_BLACK, EGDB_WIN, {0x0b800002, 0x00111000, 0x02800002},
	"W:W13,17,21:BK2,K24,25,K26,28", 8, EGDB_WHITE, EGDB_LOSS, {0x0b800002, 0x00111000, 0x02800002},
	"B:WK6,K27,K28:BK13,15,17,19,K26", 8, EGDB_BLACK, EGDB_WIN, {0x02055000, 0x0c000020, 0x0e001020},
	"W:WK6,K27,K28:BK13,15,17,19,K26", 8, EGDB_WHITE, EGDB_LOSS, {0x02055000, 0x0c000020, 0x0e001020},
	"B:WK7,K9,28:BK1,16,17,K20,26", 8, EGDB_BLACK, EGDB_WIN, {0x02098001, 0x08000140, 0x00080141},
	"W:WK7,K9,28:BK1,16,17,K20,26", 8, EGDB_WHITE, EGDB_LOSS, {0x02098001, 0x08000140, 0x00080141},
	"B:WK4,21,32:BK1,K9,12,16,19", 8, EGDB_BLACK, EGDB_WIN, {0x00048901, 0x80100008, 0x00000109},
	"W:WK4,21,32:BK1,K9,12,16,19", 8, EGDB_WHITE, EGDB_LOSS, {0x00048901, 0x80100008, 0x00000109},
	"B:W17,18,24:BK8,9,23,27,K31", 8, EGDB_BLACK, EGDB_WIN, {0x44400180, 0x00830000, 0x40000080},
	"W:W17,18,24:BK8,9,23,27,K31", 8, EGDB_WHITE, EGDB_LOSS, {0x44400180, 0x00830000, 0x40000080},
	"B:WK1,K2,K3:B5,9,15,16,K26", 8, EGDB_BLACK, EGDB_WIN, {0x0200c110, 0x00000007, 0x02000007},
	"W:WK1,K2,K3:B5,9,15,16,K26", 8, EGDB_WHITE, EGDB_LOSS, {0x0200c110, 0x00000007, 0x02000007},
	"B:WK2,K3,32:BK1,10,11,18,25", 8, EGDB_BLACK, EGDB_WIN, {0x01020601, 0x80000006, 0x00000007},
	"W:WK2,K3,32:BK1,10,11,18,25", 8, EGDB_WHITE, EGDB_LOSS, {0x01020601, 0x80000006, 0x00000007},
	"B:WK1,30,31:B7,8,13,K17,24", 8, EGDB_BLACK, EGDB_WIN, {0x008110c0, 0x60000001, 0x00010001},
	"W:WK1,30,31:B7,8,13,K17,24", 8, EGDB_WHITE, EGDB_LOSS, {0x008110c0, 0x60000001, 0x00010001},
	"B:W5,11,12:B3,6,K14,16,19", 8, EGDB_BLACK, EGDB_WIN, {0x0004a024, 0x00000c10, 0x00002000},
	"W:W5,11,12:B3,6,K14,16,19", 8, EGDB_WHITE, EGDB_LOSS, {0x0004a024, 0x00000c10, 0x00002000},
	"B:WK4,K10,K25:B3,14,17,19,28", 8, EGDB_BLACK, EGDB_WIN, {0x08052004, 0x01000208, 0x01000208},
	"W:WK4,K10,K25:B3,14,17,19,28", 8, EGDB_WHITE, EGDB_LOSS, {0x08052004, 0x01000208, 0x01000208},
	"B:WK2,K3,8:B1,13,17,19,25", 8, EGDB_BLACK, EGDB_WIN, {0x01051001, 0x00000086, 0x00000006},
	"W:WK2,K3,8:B1,13,17,19,25", 8, EGDB_WHITE, EGDB_LOSS, {0x01051001, 0x00000086, 0x00000006},
	"B:W7,22,K28:B1,9,11,19,24", 8, EGDB_BLACK, EGDB_WIN, {0x00840501, 0x08200040, 0x08000000},
	"W:W7,22,K28:B1,9,11,19,24", 8, EGDB_WHITE, EGDB_LOSS, {0x00840501, 0x08200040, 0x08000000},
	"B:W6,28,29:B4,7,17,19,24", 8, EGDB_BLACK, EGDB_WIN, {0x00850048, 0x18000020, 0x00000000},
	"W:W6,28,29:B4,7,17,19,24", 8, EGDB_WHITE, EGDB_LOSS, {0x00850048, 0x18000020, 0x00000000},
	"B:WK3,K5,K22,K31:BK13,K14,K16,K20,K29", 9, EGDB_BLACK, EGDB_WIN, {0x1008b000, 0x40200014, 0x5028b014},
	"B:WK10,K12,K15,18:BK1,K5,K13,K22,K26", 9, EGDB_BLACK, EGDB_WIN, {0x02201011, 0x00024a00, 0x02205a11},
	"B:WK1,12,K13,31:BK4,K10,K21,K24,K28", 9, EGDB_BLACK, EGDB_WIN, {0x08900208, 0x40001801, 0x08901209},
	"B:W10,K11,12,15:BK9,K13,K17,K22,K25", 9, EGDB_BLACK, EGDB_WIN, {0x01211100, 0x00004e00, 0x01211500},
	"B:W9,11,13,14:BK1,K2,K3,K4,K5", 9, EGDB_BLACK, EGDB_WIN, {0x0000001f, 0x00003500, 0x0000001f},
	"B:WK6,K14,K24,K28:BK5,K12,15,K21,K22", 9, EGDB_BLACK, EGDB_WIN, {0x00304810, 0x08802020, 0x08b02830},
	"B:WK1,K2,K3,21:BK11,16,K20,K24,K29", 9, EGDB_BLACK, EGDB_WIN, {0x10888400, 0x00100007, 0x10880407},
	"B:WK11,14,17,K24:BK6,K12,K25,26,K29", 9, EGDB_BLACK, EGDB_WIN, {0x13000820, 0x00812400, 0x11800c20},
	"B:WK3,11,19,26:BK1,K2,K9,20,K27", 9, EGDB_BLACK, EGDB_WIN, {0x04080103, 0x02040404, 0x04000107},
	"B:W10,11,27,29:BK1,K2,K3,K4,20", 9, EGDB_BLACK, EGDB_WIN, {0x0008000f, 0x14000600, 0x0000000f},
	"B:WK20,K21,K28,K29:BK9,K14,15,18,K22", 9, EGDB_BLACK, EGDB_WIN, {0x00226100, 0x18180000, 0x18382100},
	"B:WK2,K16,24,K32:BK4,17,21,K25,K26", 9, EGDB_BLACK, EGDB_WIN, {0x03110008, 0x80808002, 0x8300800a},
	"B:WK14,17,24,K30:BK7,12,27,K29,K31", 9, EGDB_BLACK, EGDB_WIN, {0x54000840, 0x20812000, 0x70002040},
	"B:WK1,13,17,21:BK2,K24,25,K26,28", 9, EGDB_BLACK, EGDB_WIN, {0x0b800002, 0x00111001, 0x02800003},
	"B:W12,15,21,26:BK1,K2,K3,9,28", 9, EGDB_BLACK, EGDB_WIN, {0x08000107, 0x02104800, 0x00000007},
	"B:WK2,K4,K24,K28:BK9,14,15,19,K29", 9, EGDB_BLACK, EGDB_DRAW, {0x10046100, 0x0880000a, 0x1880010a},
	"B:WK12,K13,K20,27:B11,15,16,K19,K21", 9, EGDB_BLACK, EGDB_DRAW, {0x0014c400, 0x04081800, 0x001c1800},
	"B:WK3,K8,20,24:BK5,K6,10,25,27", 9, EGDB_BLACK, EGDB_WIN, {0x05000230, 0x00880084, 0x000000b4},
	"B:W17,18,K22,24:BK3,K5,10,23,27", 9, EGDB_BLACK, EGDB_WIN, {0x04400214, 0x00a30000, 0x00200014},
	"B:W15,28,31,32:BK1,K2,6,13,17", 9, EGDB_BLACK, EGDB_WIN, {0x00011023, 0xc8004000, 0x00000003},
	"B:WK1,K2,K3,K4:B5,9,15,16,K26", 9, EGDB_BLACK, EGDB_WIN, {0x0200c110, 0x0000000f, 0x0200000f},
	"B:WK2,K3,K4,32:BK1,10,11,18,25", 9, EGDB_BLACK, EGDB_DRAW, {0x01020601, 0x8000000e, 0x0000000f},
	"B:WK2,K3,27,31:BK1,20,22,25,28", 9, EGDB_BLACK, EGDB_WIN, {0x09280001, 0x44000006, 0x00000007},
	"B:WK3,6,10,16:BK1,2,5,9,13", 9, EGDB_BLACK, EGDB_WIN, {0x00001113, 0x00008224, 0x00000005},
	"B:W5,10,18,26:BK1,2,8,12,17", 9, EGDB_BLACK, EGDB_WIN, {0x00010883, 0x02020210, 0x00000001},
	"W:W5,10,18,26:BK1,2,8,12,17", 9, EGDB_WHITE, EGDB_LOSS, {0x00010883, 0x02020210, 0x00000001},
	"W:WK1,K15,K24,K26:B3,14,17,19,28", 9, EGDB_WHITE, EGDB_WIN, {0x08052004, 0x02804001, 0x02804001},
	"W:WK2,K3,K4,8:B1,13,17,19,25", 9, EGDB_WHITE, EGDB_LOSS, {0x01051001, 0x0000008e, 0x0000000e},
	"B:WK2,K3,7,12:B1,10,13,17,27", 9, EGDB_BLACK, EGDB_WIN, {0x04011201, 0x00000846, 0x00000006},
	"B:WK3,6,28,29:B4,17,18,19,24", 9, EGDB_BLACK, EGDB_WIN, {0x00870008, 0x18000024, 0x00000004},
	"W:WK3,6,28,29:B4,17,18,19,24", 9, EGDB_WHITE, EGDB_LOSS, {0x00870008, 0x18000024, 0x00000004},
	"B:W7,14,25,32:B1,5,12,19,28", 9, EGDB_BLACK, EGDB_WIN, {0x08040811, 0x81002040, 0x00000000},
	"W:W7,14,25,32:B1,5,12,19,28", 9, EGDB_WHITE, EGDB_LOSS, {0x08040811, 0x81002040, 0x00000000},
	"B:WK2,K3,K23,K27,K31:BK13,K14,K16,K20,K29", 10, EGDB_BLACK, EGDB_DRAW, {0x1008b000, 0x44400006, 0x5448b006},
	"W:WK2,K3,K23,K27,K31:BK13,K14,K16,K20,K29", 10, EGDB_WHITE, EGDB_DRAW, {0x1008b000, 0x44400006, 0x5448b006},
	"W:WK4,K11,K15,18,K19:BK1,K5,K13,K22,K26", 10, EGDB_WHITE, EGDB_DRAW, {0x02201011, 0x00064408, 0x02245419},
	"W:WK3,12,K18,25,K32:BK1,K13,K21,K30,K31", 10, EGDB_WHITE, EGDB_LOSS, {0x60101001, 0x81020804, 0xe0121005},
	"B:W10,K14,17,18,K30:BK4,K8,K11,K19,K32", 10, EGDB_BLACK, EGDB_WIN, {0x80040488, 0x20032200, 0xa0042488},
	"B:WK1,8,23,29,30:BK5,K13,K15,K21,K24", 10, EGDB_BLACK, EGDB_WIN, {0x00905010, 0x30400081, 0x00905011},
	"B:W7,13,16,18,32:BK1,K21,K24,K25,K29", 10, EGDB_BLACK, EGDB_WIN, {0x11900001, 0x80029040, 0x11900001},
	"B:WK1,K2,K3,K4,21:BK11,16,K20,K24,K29", 10, EGDB_BLACK, EGDB_DRAW, {0x10888400, 0x0010000f, 0x1088040f},
	"W:WK1,K2,K3,K4,21:BK11,16,K20,K24,K29", 10, EGDB_WHITE, EGDB_DRAW, {0x10888400, 0x0010000f, 0x1088040f},
	"W:WK7,K13,14,17,K28:BK6,K12,K25,26,K29", 10, EGDB_WHITE, EGDB_DRAW, {0x13000820, 0x08013040, 0x19001860},
	"B:WK3,K4,11,19,26:BK1,K2,K9,20,K27", 10, EGDB_BLACK, EGDB_WIN, {0x04080103, 0x0204040c, 0x0400010f},
	"B:WK5,10,11,27,29:BK1,K2,K3,K4,20", 10, EGDB_BLACK, EGDB_WIN, {0x0008000f, 0x14000610, 0x0000001f},
	"B:W8,12,21,23,28:BK4,K10,K11,26,K30", 10, EGDB_BLACK, EGDB_WIN, {0x22000608, 0x08500880, 0x20000608},
	"B:WK2,K5,15,K19,30:BK4,K13,K17,20,28", 10, EGDB_BLACK, EGDB_DRAW, {0x08091008, 0x20044012, 0x0005101a},
	"W:WK2,K5,15,K19,30:BK4,K13,K17,20,28", 10, EGDB_WHITE, EGDB_DRAW, {0x08091008, 0x20044012, 0x0005101a},
	"W:WK1,K3,13,17,21:BK2,K24,25,K26,28", 10, EGDB_WHITE, EGDB_DRAW, {0x0b800002, 0x00111005, 0x02800007},
	"B:WK4,12,15,21,26:BK1,K2,K3,9,28", 10, EGDB_BLACK, EGDB_WIN, {0x08000107, 0x02104808, 0x0000000f},
	"B:W11,13,16,22,26:BK3,K4,6,K20,25", 10, EGDB_BLACK, EGDB_WIN, {0x0108002c, 0x02209400, 0x0008000c},
	"B:W17,K20,24,25,K28:BK1,K8,11,15,18", 10, EGDB_BLACK, EGDB_DRAW, {0x00024481, 0x09890000, 0x08080081},
	"W:W17,K20,24,25,K28:BK1,K8,11,15,18", 10, EGDB_WHITE, EGDB_DRAW, {0x00024481, 0x09890000, 0x08080081},
	"B:WK3,15,28,31,32:BK1,K2,6,13,17", 10, EGDB_BLACK, EGDB_WIN, {0x00011023, 0xc8004004, 0x00000007},
	"B:W12,18,22,29,32:BK10,K19,20,21,24", 10, EGDB_BLACK, EGDB_WIN, {0x009c0200, 0x90220800, 0x00040200},
	"B:W5,10,18,K23,26:B2,8,K11,12,17", 10, EGDB_BLACK, EGDB_DRAW, {0x00010c82, 0x02420210, 0x00400400},
	"W:W5,10,18,K23,26:B2,8,K11,12,17", 10, EGDB_WHITE, EGDB_DRAW, {0x00010c82, 0x02420210, 0x00400400},
	"B:W19,25,27,29,30:B6,K8,10,14,21", 10, EGDB_BLACK, EGDB_WIN, {0x001022a0, 0x35040000, 0x00000080},
	"W:W19,25,27,29,30:B6,K8,10,14,21", 10, EGDB_WHITE, EGDB_LOSS, {0x001022a0, 0x35040000, 0x00000080},
	"B:W7,11,15,19,28:B1,5,13,17,27", 10, EGDB_BLACK, EGDB_DRAW, {0x04011011, 0x08044440, 0x00000000},
	"W:W7,11,15,19,28:B1,5,13,17,27", 10, EGDB_WHITE, EGDB_DRAW, {0x04011011, 0x08044440, 0x00000000},
#endif
#ifdef ITALIAN_RULES
	"B:WK3:BK20", 2, EGDB_BLACK, EGDB_DRAW, {0x00010000, 0x00000002, 0x00010002},
	"W:WK3:BK20", 2, EGDB_WHITE, EGDB_DRAW, {0x00010000, 0x00000002, 0x00010002},
	"B:W19:BK3", 2, EGDB_BLACK, EGDB_DRAW, {0x00000002, 0x00020000, 0x00000002},
	"W:W19:BK3", 2, EGDB_WHITE, EGDB_LOSS, {0x00000002, 0x00020000, 0x00000002},
	"B:W24:B11", 2, EGDB_BLACK, EGDB_WIN, {0x00000200, 0x00100000, 0x00000000},
	"W:W24:B11", 2, EGDB_WHITE, EGDB_DRAW, {0x00000200, 0x00100000, 0x00000000},
	"B:WK3:BK19,K22", 3, EGDB_BLACK, EGDB_WIN, {0x00420000, 0x00000002, 0x00420002},
	"W:WK3:BK19,K22", 3, EGDB_WHITE, EGDB_LOSS, {0x00420000, 0x00000002, 0x00420002},
	"B:W19:BK4,K2", 3, EGDB_BLACK, EGDB_WIN, {0x00000005, 0x00020000, 0x00000005},
	"W:W19:BK4,K2", 3, EGDB_WHITE, EGDB_LOSS, {0x00000005, 0x00020000, 0x00000005},
	"B:WK2:BK4,14", 3, EGDB_BLACK, EGDB_WIN, {0x00004001, 0x00000004, 0x00000005},
	"W:WK2:BK4,14", 3, EGDB_WHITE, EGDB_LOSS, {0x00004001, 0x00000004, 0x00000005},
	"B:W24:BK3,12", 3, EGDB_BLACK, EGDB_WIN, {0x00000102, 0x00100000, 0x00000002},
	"W:W24:BK3,12", 3, EGDB_WHITE, EGDB_LOSS, {0x00000102, 0x00100000, 0x00000002},
	"B:WK3:B15,19", 3, EGDB_BLACK, EGDB_WIN, {0x00022000, 0x00000002, 0x00000002},
	"W:WK3:B15,19", 3, EGDB_WHITE, EGDB_LOSS, {0x00022000, 0x00000002, 0x00000002},
	"B:W21:B8,6", 3, EGDB_BLACK, EGDB_WIN, {0x00000050, 0x00800000, 0x00000000},
	"W:W21:B8,6", 3, EGDB_WHITE, EGDB_LOSS, {0x00000050, 0x00800000, 0x00000000},
	"B:WK3,K1:BK19,K22", 4, EGDB_BLACK, EGDB_DRAW, {0x00420000, 0x0000000a, 0x0042000a},
	"W:WK3,K1:BK19,K22", 4, EGDB_WHITE, EGDB_DRAW, {0x00420000, 0x0000000a, 0x0042000a},
	"B:WK11,19:BK4,K3", 4, EGDB_BLACK, EGDB_DRAW, {0x00000003, 0x00020200, 0x00000203},
	"W:WK11,19:BK4,K3", 4, EGDB_WHITE, EGDB_DRAW, {0x00000003, 0x00020200, 0x00000203},
	"B:W16,15:BK4,K1", 4, EGDB_BLACK, EGDB_WIN, {0x00000009, 0x00003000, 0x00000009},
	"W:W16,15:BK4,K1", 4, EGDB_WHITE, EGDB_LOSS, {0x00000009, 0x00003000, 0x00000009},
	"B:WK18,24:BK4,12", 4, EGDB_BLACK, EGDB_DRAW, {0x00000101, 0x00140000, 0x00040001},
	"W:WK18,24:BK4,12", 4, EGDB_WHITE, EGDB_DRAW, {0x00000101, 0x00140000, 0x00040001},
	"B:W14,21:BK1,8", 4, EGDB_BLACK, EGDB_DRAW, {0x00000018, 0x00804000, 0x00000008},
	"W:W14,21:BK1,8", 4, EGDB_WHITE, EGDB_DRAW, {0x00000018, 0x00804000, 0x00000008},
	"B:W20,27:B9,18", 4, EGDB_BLACK, EGDB_DRAW, {0x00040800, 0x02010000, 0x00000000},
	"W:W20,27:B9,18", 4, EGDB_WHITE, EGDB_DRAW, {0x00040800, 0x02010000, 0x00000000},
	"B:WK2:BK11,K17,K27", 4, EGDB_BLACK, EGDB_WIN, {0x02080200, 0x00000004, 0x02080204},
	"W:WK2:BK11,K17,K27", 4, EGDB_WHITE, EGDB_LOSS, {0x02080200, 0x00000004, 0x02080204},
	"B:W19:BK4,K2,K1", 4, EGDB_BLACK, EGDB_WIN, {0x0000000d, 0x00020000, 0x0000000d},
	"W:W19:BK4,K2,K1", 4, EGDB_WHITE, EGDB_LOSS, {0x0000000d, 0x00020000, 0x0000000d},
	"B:WK28:BK4,K3,14", 4, EGDB_BLACK, EGDB_WIN, {0x00004003, 0x01000000, 0x01000003},
	"W:WK28:BK4,K3,14", 4, EGDB_WHITE, EGDB_LOSS, {0x00004003, 0x01000000, 0x01000003},
	"B:W24:BK4,K8,12", 4, EGDB_BLACK, EGDB_WIN, {0x00000111, 0x00100000, 0x00000011},
	"W:W24:BK4,K8,12", 4, EGDB_WHITE, EGDB_LOSS, {0x00000111, 0x00100000, 0x00000011},
	"B:WK5:BK4,15,19", 4, EGDB_BLACK, EGDB_WIN, {0x00022001, 0x00000080, 0x00000081},
	"W:WK5:BK4,15,19", 4, EGDB_WHITE, EGDB_LOSS, {0x00022001, 0x00000080, 0x00000081},
	"B:W21:BK1,8,7", 4, EGDB_BLACK, EGDB_WIN, {0x00000038, 0x00800000, 0x00000008},
	"W:W21:BK1,8,7", 4, EGDB_WHITE, EGDB_LOSS, {0x00000038, 0x00800000, 0x00000008},
	"B:WK2:B7,9,18", 4, EGDB_BLACK, EGDB_WIN, {0x00040820, 0x00000004, 0x00000004},
	"W:WK2:B7,9,18", 4, EGDB_WHITE, EGDB_LOSS, {0x00040820, 0x00000004, 0x00000004},
	"B:W25:B7,15,22", 4, EGDB_BLACK, EGDB_WIN, {0x00402020, 0x08000000, 0x00000000},
	"W:W25:B7,15,22", 4, EGDB_WHITE, EGDB_LOSS, {0x00402020, 0x08000000, 0x00000000},
	"B:WK8,K10:BK11,K17,K27", 5, EGDB_BLACK, EGDB_WIN, {0x02080200, 0x00000410, 0x02080610},
	"W:WK8,K10:BK11,K17,K27", 5, EGDB_WHITE, EGDB_LOSS, {0x02080200, 0x00000410, 0x02080610},
	"B:W19,K18:BK4,K2,K1", 5, EGDB_BLACK, EGDB_WIN, {0x0000000d, 0x00060000, 0x0004000d},
	"W:W19,K18:BK4,K2,K1", 5, EGDB_WHITE, EGDB_LOSS, {0x0000000d, 0x00060000, 0x0004000d},
	"B:W16,15:BK4,K7,K6", 5, EGDB_BLACK, EGDB_WIN, {0x00000061, 0x00003000, 0x00000061},
	"W:W16,15:BK4,K7,K6", 5, EGDB_WHITE, EGDB_LOSS, {0x00000061, 0x00003000, 0x00000061},
	"B:WK2,K28:BK4,K3,14", 5, EGDB_BLACK, EGDB_WIN, {0x00004003, 0x01000004, 0x01000007},
	"W:WK2,K28:BK4,K3,14", 5, EGDB_WHITE, EGDB_LOSS, {0x00004003, 0x01000004, 0x01000007},
	"B:W24,K28:BK4,K7,12", 5, EGDB_BLACK, EGDB_WIN, {0x00000121, 0x01100000, 0x01000021},
	"W:W24,K28:BK4,K7,12", 5, EGDB_WHITE, EGDB_LOSS, {0x00000121, 0x01100000, 0x01000021},
	"B:W14,21:BK2,8,K22", 5, EGDB_BLACK, EGDB_WIN, {0x00400014, 0x00804000, 0x00400004},
	"W:W14,21:BK2,8,K22", 5, EGDB_WHITE, EGDB_LOSS, {0x00400014, 0x00804000, 0x00400004},
	"B:WK2,K8:BK4,15,19", 5, EGDB_BLACK, EGDB_WIN, {0x00022001, 0x00000014, 0x00000015},
	"W:WK2,K8:BK4,15,19", 5, EGDB_WHITE, EGDB_DRAW, {0x00022001, 0x00000014, 0x00000015},
	"B:W21,K27:B8,7,K5", 5, EGDB_BLACK, EGDB_WIN, {0x000000b0, 0x02800000, 0x02000080},
	"W:W21,K27:B8,7,K5", 5, EGDB_WHITE, EGDB_DRAW, {0x000000b0, 0x02800000, 0x02000080},
	"B:W20,27:B11,K13,18", 5, EGDB_BLACK, EGDB_WIN, {0x00048200, 0x02010000, 0x00008000},
	"W:W20,27:B11,K13,18", 5, EGDB_WHITE, EGDB_LOSS, {0x00048200, 0x02010000, 0x00008000},
	"B:WK16,K17:B7,9,18", 5, EGDB_BLACK, EGDB_LOSS, {0x00040820, 0x00081000, 0x00081000},
	"W:WK16,K17:B7,9,18", 5, EGDB_WHITE, EGDB_WIN, {0x00040820, 0x00081000, 0x00081000},
	"B:WK24,25:B6,15,22", 5, EGDB_BLACK, EGDB_DRAW, {0x00402040, 0x08100000, 0x00100000},
	"W:WK24,25:B6,15,22", 5, EGDB_WHITE, EGDB_DRAW, {0x00402040, 0x08100000, 0x00100000},
	"B:W24,32:B16,13,21", 5, EGDB_BLACK, EGDB_WIN, {0x00809000, 0x10100000, 0x00000000},
	"W:W24,32:B16,13,21", 5, EGDB_WHITE, EGDB_LOSS, {0x00809000, 0x10100000, 0x00000000},
	"B:WK13:BK3,K16,K14,K25", 5, EGDB_BLACK, EGDB_WIN, {0x08005002, 0x00008000, 0x0800d002},
	"W:WK13:BK3,K16,K14,K25", 5, EGDB_WHITE, EGDB_LOSS, {0x08005002, 0x00008000, 0x0800d002},
	"B:W19:BK3,K2,K8,K7", 5, EGDB_BLACK, EGDB_WIN, {0x00000036, 0x00020000, 0x00000036},
	"W:W19:BK3,K2,K8,K7", 5, EGDB_WHITE, EGDB_LOSS, {0x00000036, 0x00020000, 0x00000036},
	"B:WK3:BK4,K2,K8,14", 5, EGDB_BLACK, EGDB_WIN, {0x00004015, 0x00000002, 0x00000017},
	"W:WK3:BK4,K2,K8,14", 5, EGDB_WHITE, EGDB_LOSS, {0x00004015, 0x00000002, 0x00000017},
	"B:W24:BK3,K2,K7,12", 5, EGDB_BLACK, EGDB_WIN, {0x00000126, 0x00100000, 0x00000026},
	"W:W24:BK3,K2,K7,12", 5, EGDB_WHITE, EGDB_LOSS, {0x00000126, 0x00100000, 0x00000026},
	"B:WK13:BK4,K1,15,19", 5, EGDB_BLACK, EGDB_WIN, {0x00022009, 0x00008000, 0x00008009},
	"W:WK13:BK4,K1,15,19", 5, EGDB_WHITE, EGDB_LOSS, {0x00022009, 0x00008000, 0x00008009},
	"B:W21:B8,7,K6,K10", 5, EGDB_BLACK, EGDB_WIN, {0x00000470, 0x00800000, 0x00000440},
	"W:W21:B8,7,K6,K10", 5, EGDB_WHITE, EGDB_LOSS, {0x00000470, 0x00800000, 0x00000440},
	"B:WK30:BK8,7,9,18", 5, EGDB_BLACK, EGDB_WIN, {0x00040830, 0x40000000, 0x40000010},
	"W:WK30:BK8,7,9,18", 5, EGDB_WHITE, EGDB_LOSS, {0x00040830, 0x40000000, 0x40000010},
	"B:W25:BK4,7,15,22", 5, EGDB_BLACK, EGDB_WIN, {0x00402021, 0x08000000, 0x00000001},
	"W:W25:BK4,7,15,22", 5, EGDB_WHITE, EGDB_LOSS, {0x00402021, 0x08000000, 0x00000001},
	"B:WK32:B7,6,16,13", 5, EGDB_BLACK, EGDB_WIN, {0x00009060, 0x10000000, 0x10000000},
	"W:WK32:B7,6,16,13", 5, EGDB_WHITE, EGDB_LOSS, {0x00009060, 0x10000000, 0x10000000},
	"B:W29:B11,13,18,22", 5, EGDB_BLACK, EGDB_WIN, {0x00448200, 0x80000000, 0x00000000},
	"W:W29:B11,13,18,22", 5, EGDB_WHITE, EGDB_LOSS, {0x00448200, 0x80000000, 0x00000000},
	"B:WK9,K16,K26:BK11,K17,K27", 6, EGDB_BLACK, EGDB_DRAW, {0x02080200, 0x04001800, 0x06081a00},
	"W:WK9,K16,K26:BK11,K17,K27", 6, EGDB_WHITE, EGDB_DRAW, {0x02080200, 0x04001800, 0x06081a00},
	"B:WK6,K11,19:BK4,K2,K1", 6, EGDB_BLACK, EGDB_WIN, {0x0000000d, 0x00020240, 0x0000024d},
	"W:WK6,K11,19:BK4,K2,K1", 6, EGDB_WHITE, EGDB_DRAW, {0x0000000d, 0x00020240, 0x0000024d},
	"B:W16,15,K14:BK4,K3,K1", 6, EGDB_BLACK, EGDB_WIN, {0x0000000b, 0x00007000, 0x0000400b},
	"W:W16,15,K14:BK4,K3,K1", 6, EGDB_WHITE, EGDB_LOSS, {0x0000000b, 0x00007000, 0x0000400b},
	"B:W11,19,28:BK1,K9,K20", 6, EGDB_BLACK, EGDB_WIN, {0x00010808, 0x01020200, 0x00010808},
	"W:W11,19,28:BK1,K9,K20", 6, EGDB_WHITE, EGDB_LOSS, {0x00010808, 0x01020200, 0x00010808},
	"B:WK11,K20,24:BK3,K1,12", 6, EGDB_BLACK, EGDB_DRAW, {0x0000010a, 0x00110200, 0x0001020a},
	"W:WK11,K20,24:BK3,K1,12", 6, EGDB_WHITE, EGDB_WIN, {0x0000010a, 0x00110200, 0x0001020a},
	"B:WK4,14,21:B8,K12,K16", 6, EGDB_BLACK, EGDB_DRAW, {0x00001110, 0x00804001, 0x00001101},
	"W:WK4,14,21:B8,K12,K16", 6, EGDB_WHITE, EGDB_DRAW, {0x00001110, 0x00804001, 0x00001101},
	"B:W10,24,25:BK8,K11,23", 6, EGDB_BLACK, EGDB_WIN, {0x00200210, 0x08100400, 0x00000210},
	"W:W10,24,25:BK8,K11,23", 6, EGDB_WHITE, EGDB_LOSS, {0x00200210, 0x08100400, 0x00000210},
	"B:W20,K23,27:BK7,10,18", 6, EGDB_BLACK, EGDB_DRAW, {0x00040420, 0x02210000, 0x00200020},
	"W:W20,K23,27:BK7,10,18", 6, EGDB_WHITE, EGDB_DRAW, {0x00040420, 0x02210000, 0x00200020},
	"B:W16,19,24:BK4,21,28", 6, EGDB_BLACK, EGDB_WIN, {0x01800001, 0x00121000, 0x00000001},
	"W:W16,19,24:BK4,21,28", 6, EGDB_WHITE, EGDB_LOSS, {0x01800001, 0x00121000, 0x00000001},
	"B:W19,24,31:B7,11,26", 6, EGDB_BLACK, EGDB_WIN, {0x04000220, 0x20120000, 0x00000000},
	"W:W19,24,31:B7,11,26", 6, EGDB_WHITE, EGDB_DRAW, {0x04000220, 0x20120000, 0x00000000},
	"B:WK28,K32:BK2,K16,K14,K25", 6, EGDB_BLACK, EGDB_WIN, {0x08005004, 0x11000000, 0x19005004},
	"W:WK28,K32:BK2,K16,K14,K25", 6, EGDB_WHITE, EGDB_LOSS, {0x08005004, 0x11000000, 0x19005004},
	"B:W19,K17:BK3,K2,K1,K7", 6, EGDB_BLACK, EGDB_WIN, {0x0000002e, 0x000a0000, 0x0008002e},
	"W:W19,K17:BK3,K2,K1,K7", 6, EGDB_WHITE, EGDB_LOSS, {0x0000002e, 0x000a0000, 0x0008002e},
	"B:W16,15:BK4,K3,K8,K7", 6, EGDB_BLACK, EGDB_WIN, {0x00000033, 0x00003000, 0x00000033},
	"W:W16,15:BK4,K3,K8,K7", 6, EGDB_WHITE, EGDB_LOSS, {0x00000033, 0x00003000, 0x00000033},
	"B:WK17,K27:BK2,K1,K8,14", 6, EGDB_BLACK, EGDB_WIN, {0x0000401c, 0x02080000, 0x0208001c},
	"W:WK17,K27:BK2,K1,K8,14", 6, EGDB_WHITE, EGDB_LOSS, {0x0000401c, 0x02080000, 0x0208001c},
	"B:WK13,24:BK3,K1,K5,12", 6, EGDB_BLACK, EGDB_WIN, {0x0000018a, 0x00108000, 0x0000808a},
	"W:WK13,24:BK3,K1,K5,12", 6, EGDB_WHITE, EGDB_LOSS, {0x0000018a, 0x00108000, 0x0000808a},
	"B:W14,21:BK7,6,K20,K22", 6, EGDB_BLACK, EGDB_WIN, {0x00410060, 0x00804000, 0x00410020},
	"W:W14,21:BK7,6,K20,K22", 6, EGDB_WHITE, EGDB_LOSS, {0x00410060, 0x00804000, 0x00410020},
	"B:WK12,K27:BK4,K3,15,19", 6, EGDB_BLACK, EGDB_WIN, {0x00022003, 0x02000100, 0x02000103},
	"W:WK12,K27:BK4,K3,15,19", 6, EGDB_WHITE, EGDB_LOSS, {0x00022003, 0x02000100, 0x02000103},
	"B:WK4,21:B8,7,K11,K15", 6, EGDB_BLACK, EGDB_WIN, {0x00002230, 0x00800001, 0x00002201},
	"W:WK4,21:B8,7,K11,K15", 6, EGDB_WHITE, EGDB_LOSS, {0x00002230, 0x00800001, 0x00002201},
	"B:W13,27:BK8,19,18,K32", 6, EGDB_BLACK, EGDB_WIN, {0x10060010, 0x02008000, 0x10000010},
	"W:W13,27:BK8,19,18,K32", 6, EGDB_WHITE, EGDB_LOSS, {0x10060010, 0x02008000, 0x10000010},
	"B:WK8,K30:BK3,7,9,18", 6, EGDB_BLACK, EGDB_WIN, {0x00040822, 0x40000010, 0x40000012},
	"W:WK8,K30:BK3,7,9,18", 6, EGDB_WHITE, EGDB_LOSS, {0x00040822, 0x40000010, 0x40000012},
	"B:W25,K30:BK6,5,15,22", 6, EGDB_BLACK, EGDB_WIN, {0x004020c0, 0x48000000, 0x40000040},
	"W:W25,K30:BK6,5,15,22", 6, EGDB_WHITE, EGDB_LOSS, {0x004020c0, 0x48000000, 0x40000040},
	"B:W24,32:BK11,14,19,21", 6, EGDB_BLACK, EGDB_WIN, {0x00824200, 0x10100000, 0x00000200},
	"W:W24,32:BK11,14,19,21", 6, EGDB_WHITE, EGDB_LOSS, {0x00824200, 0x10100000, 0x00000200},
	"B:WK8,K32:B7,6,16,13", 6, EGDB_BLACK, EGDB_DRAW, {0x00009060, 0x10000010, 0x10000010},
	"W:WK8,K32:B7,6,16,13", 6, EGDB_WHITE, EGDB_DRAW, {0x00009060, 0x10000010, 0x10000010},
	"B:WK12,29:B5,13,18,22", 6, EGDB_BLACK, EGDB_WIN, {0x00448080, 0x80000100, 0x00000100},
	"W:WK12,29:B5,13,18,22", 6, EGDB_WHITE, EGDB_LOSS, {0x00448080, 0x80000100, 0x00000100},
	"B:W8,10:B2,12,13,26", 6, EGDB_BLACK, EGDB_WIN, {0x04008104, 0x00000410, 0x00000000},
	"W:W8,10:B2,12,13,26", 6, EGDB_WHITE, EGDB_LOSS, {0x04008104, 0x00000410, 0x00000000},
	"B:WK3:BK4,K2,K5,K19,K32", 6, EGDB_BLACK, EGDB_WIN, {0x10020085, 0x00000002, 0x10020087},
	"W:WK3:BK4,K2,K5,K19,K32", 6, EGDB_WHITE, EGDB_LOSS, {0x10020085, 0x00000002, 0x10020087},
	"B:W19:BK4,K3,K7,K6,K5", 6, EGDB_BLACK, EGDB_WIN, {0x000000e3, 0x00020000, 0x000000e3},
	"W:W19:BK4,K3,K7,K6,K5", 6, EGDB_WHITE, EGDB_LOSS, {0x000000e3, 0x00020000, 0x000000e3},
	"B:WK17:BK3,K2,K1,K7,14", 6, EGDB_BLACK, EGDB_WIN, {0x0000402e, 0x00080000, 0x0008002e},
	"W:WK17:BK3,K2,K1,K7,14", 6, EGDB_WHITE, EGDB_LOSS, {0x0000402e, 0x00080000, 0x0008002e},
	"B:W24:BK8,K7,K6,12,K9", 6, EGDB_BLACK, EGDB_WIN, {0x00000970, 0x00100000, 0x00000870},
	"W:W24:BK8,K7,K6,12,K9", 6, EGDB_WHITE, EGDB_LOSS, {0x00000970, 0x00100000, 0x00000870},
	"B:WK16:BK4,K3,K1,15,19", 6, EGDB_BLACK, EGDB_WIN, {0x0002200b, 0x00001000, 0x0000100b},
	"W:WK16:BK4,K3,K1,15,19", 6, EGDB_WHITE, EGDB_LOSS, {0x0002200b, 0x00001000, 0x0000100b},
	"B:W21:B8,7,K14,K20,K19", 6, EGDB_BLACK, EGDB_WIN, {0x00034030, 0x00800000, 0x00034000},
	"W:W21:B8,7,K14,K20,K19", 6, EGDB_WHITE, EGDB_LOSS, {0x00034030, 0x00800000, 0x00034000},
	"B:WK27:B7,K12,9,K16,18", 6, EGDB_BLACK, EGDB_WIN, {0x00041920, 0x02000000, 0x02001100},
	"W:WK27:B7,K12,9,K16,18", 6, EGDB_WHITE, EGDB_LOSS, {0x00041920, 0x02000000, 0x02001100},
	"B:W25:B8,K12,K10,15,22", 6, EGDB_BLACK, EGDB_WIN, {0x00402510, 0x08000000, 0x00000500},
	"W:W25:B8,K12,K10,15,22", 6, EGDB_WHITE, EGDB_LOSS, {0x00402510, 0x08000000, 0x00000500},
	"B:WK20:B7,6,16,13,K32", 6, EGDB_BLACK, EGDB_WIN, {0x10009060, 0x00010000, 0x10010000},
	"W:WK20:B7,6,16,13,K32", 6, EGDB_WHITE, EGDB_LOSS, {0x10009060, 0x00010000, 0x10010000},
	"B:W29:B5,K12,13,18,22", 6, EGDB_BLACK, EGDB_WIN, {0x00448180, 0x80000000, 0x00000100},
	"W:W29:B5,K12,13,18,22", 6, EGDB_WHITE, EGDB_LOSS, {0x00448180, 0x80000000, 0x00000100},
	"B:WK26:B4,8,16,15,25", 6, EGDB_BLACK, EGDB_WIN, {0x08003011, 0x04000000, 0x04000000},
	"W:WK26:B4,8,16,15,25", 6, EGDB_WHITE, EGDB_LOSS, {0x08003011, 0x04000000, 0x04000000},
	"B:W11:B2,8,10,20,27", 6, EGDB_BLACK, EGDB_WIN, {0x02010414, 0x00000200, 0x00000000},
	"W:W11:B2,8,10,20,27", 6, EGDB_WHITE, EGDB_LOSS, {0x02010414, 0x00000200, 0x00000000},
	"B:WK20,K27,K31:BK1,K12,K13,K25", 7, EGDB_BLACK, EGDB_WIN, {0x08008108, 0x22010000, 0x2a018108},
	"W:WK20,K27,K31:BK1,K12,K13,K25", 7, EGDB_WHITE, EGDB_LOSS, {0x08008108, 0x22010000, 0x2a018108},
	"B:W19,K23,K30:BK4,K7,K5,K11", 7, EGDB_BLACK, EGDB_WIN, {0x000002a1, 0x40220000, 0x402002a1},
	"W:W19,K23,K30:BK4,K7,K5,K11", 7, EGDB_WHITE, EGDB_LOSS, {0x000002a1, 0x40220000, 0x402002a1},
	"B:WK2,16,15:BK4,K8,K14,K18", 7, EGDB_BLACK, EGDB_WIN, {0x00044011, 0x00003004, 0x00044015},
	"W:WK2,16,15:BK4,K8,K14,K18", 7, EGDB_WHITE, EGDB_LOSS, {0x00044011, 0x00003004, 0x00044015},
	"B:W11,19,21:BK6,K15,K24,K22", 7, EGDB_BLACK, EGDB_WIN, {0x00502040, 0x00820200, 0x00502040},
	"W:W11,19,21:BK6,K15,K24,K22", 7, EGDB_WHITE, EGDB_LOSS, {0x00502040, 0x00820200, 0x00502040},
	"B:WK27,K32,K29:BK8,K7,K5,14", 7, EGDB_BLACK, EGDB_DRAW, {0x000040b0, 0x92000000, 0x920000b0},
	"W:WK27,K32,K29:BK8,K7,K5,14", 7, EGDB_WHITE, EGDB_DRAW, {0x000040b0, 0x92000000, 0x920000b0},
	"B:WK1,K18,24:BK3,12,K16,K19", 7, EGDB_BLACK, EGDB_WIN, {0x00021102, 0x00140008, 0x0006100a},
	"W:WK1,K18,24:BK3,12,K16,K19", 7, EGDB_WHITE, EGDB_LOSS, {0x00021102, 0x00140008, 0x0006100a},
	"B:WK7,14,21:BK1,5,K22,K29", 7, EGDB_BLACK, EGDB_WIN, {0x80400088, 0x00804020, 0x80400028},
	"W:WK7,14,21:BK1,5,K22,K29", 7, EGDB_WHITE, EGDB_LOSS, {0x80400088, 0x00804020, 0x80400028},
	"B:W9,23,26:BK2,12,K16,K15", 7, EGDB_BLACK, EGDB_WIN, {0x00003104, 0x04200800, 0x00003004},
	"W:W9,23,26:BK2,12,K16,K15", 7, EGDB_WHITE, EGDB_LOSS, {0x00003104, 0x04200800, 0x00003004},
	"B:WK1,K16,K28:BK10,K9,15,19", 7, EGDB_BLACK, EGDB_DRAW, {0x00022c00, 0x01001008, 0x01001c08},
	"W:WK1,K16,K28:BK10,K9,15,19", 7, EGDB_WHITE, EGDB_DRAW, {0x00022c00, 0x01001008, 0x01001c08},
	"B:WK19,21,K32:BK7,6,5,K29", 7, EGDB_BLACK, EGDB_WIN, {0x800000e0, 0x10820000, 0x90020020},
	"W:WK19,21,K32:BK7,6,5,K29", 7, EGDB_WHITE, EGDB_LOSS, {0x800000e0, 0x10820000, 0x90020020},
	"B:W20,27,K29:B7,K5,K11,24", 7, EGDB_BLACK, EGDB_WIN, {0x001002a0, 0x82010000, 0x80000280},
	"W:W20,27,K29:B7,K5,K11,24", 7, EGDB_WHITE, EGDB_LOSS, {0x001002a0, 0x82010000, 0x80000280},
	"B:W14,17,24:BK4,9,15,K21", 7, EGDB_BLACK, EGDB_WIN, {0x00802801, 0x00184000, 0x00800001},
	"W:W14,17,24:BK4,9,15,K21", 7, EGDB_WHITE, EGDB_LOSS, {0x00802801, 0x00184000, 0x00800001},
	"B:WK12,K28,K26:B11,9,18,K17", 7, EGDB_BLACK, EGDB_DRAW, {0x000c0a00, 0x05000100, 0x05080100},
	"W:WK12,K28,K26:B11,9,18,K17", 7, EGDB_WHITE, EGDB_WIN, {0x000c0a00, 0x05000100, 0x05080100},
	"B:WK3,K5,25:B9,14,K18,22", 7, EGDB_BLACK, EGDB_WIN, {0x00444800, 0x08000082, 0x00040082},
	"W:WK3,K5,25:B9,14,K18,22", 7, EGDB_WHITE, EGDB_LOSS, {0x00444800, 0x08000082, 0x00040082},
	"B:WK3,24,32:BK4,10,18,27", 7, EGDB_BLACK, EGDB_WIN, {0x02040401, 0x10100002, 0x00000003},
	"W:WK3,24,32:BK4,10,18,27", 7, EGDB_WHITE, EGDB_LOSS, {0x02040401, 0x10100002, 0x00000003},
	"B:W20,24,32:B12,18,23,K26", 7, EGDB_BLACK, EGDB_WIN, {0x04240100, 0x10110000, 0x04000000},
	"W:W20,24,32:B12,18,23,K26", 7, EGDB_WHITE, EGDB_LOSS, {0x04240100, 0x10110000, 0x04000000},
	"B:WK1,K20,K27:B8,12,16,13", 7, EGDB_BLACK, EGDB_LOSS, {0x00009110, 0x02010008, 0x02010008},
	"W:WK1,K20,K27:B8,12,16,13", 7, EGDB_WHITE, EGDB_WIN, {0x00009110, 0x02010008, 0x02010008},
	"B:WK6,K15,29:B8,13,17,22", 7, EGDB_BLACK, EGDB_DRAW, {0x00488010, 0x80002040, 0x00002040},
	"W:WK6,K15,29:B8,13,17,22", 7, EGDB_WHITE, EGDB_DRAW, {0x00488010, 0x80002040, 0x00002040},
	"B:W8,11,K22:B2,5,16,14", 7, EGDB_BLACK, EGDB_LOSS, {0x00005084, 0x00400210, 0x00400000},
	"W:W8,11,K22:B2,5,16,14", 7, EGDB_WHITE, EGDB_WIN, {0x00005084, 0x00400210, 0x00400000},
	"B:W8,11,29:B1,14,21,27", 7, EGDB_BLACK, EGDB_WIN, {0x02804008, 0x80000210, 0x00000000},
	"W:W8,11,29:B1,14,21,27", 7, EGDB_WHITE, EGDB_LOSS, {0x02804008, 0x80000210, 0x00000000},
	"B:WK1,K17:BK7,K6,K11,K19,K32", 7, EGDB_BLACK, EGDB_WIN, {0x10020260, 0x00080008, 0x100a0268},
	"W:WK1,K17:BK7,K6,K11,K19,K32", 7, EGDB_WHITE, EGDB_LOSS, {0x10020260, 0x00080008, 0x100a0268},
	"B:W19,K17:BK1,K8,K6,K11,K16", 7, EGDB_BLACK, EGDB_WIN, {0x00001258, 0x000a0000, 0x00081258},
	"W:W19,K17:BK1,K8,K6,K11,K16", 7, EGDB_WHITE, EGDB_LOSS, {0x00001258, 0x000a0000, 0x00081258},
	"B:W16,15:BK2,K8,K6,K5,K21", 7, EGDB_BLACK, EGDB_WIN, {0x008000d4, 0x00003000, 0x008000d4},
	"W:W16,15:BK2,K8,K6,K5,K21", 7, EGDB_WHITE, EGDB_LOSS, {0x008000d4, 0x00003000, 0x008000d4},
	"B:WK23,K30:BK4,K7,K5,K11,14", 7, EGDB_BLACK, EGDB_WIN, {0x000042a1, 0x40200000, 0x402002a1},
	"W:WK23,K30:BK4,K7,K5,K11,14", 7, EGDB_WHITE, EGDB_LOSS, {0x000042a1, 0x40200000, 0x402002a1},
	"B:WK6,24:B12,K9,K18,K17,K28", 7, EGDB_BLACK, EGDB_WIN, {0x010c0900, 0x00100040, 0x010c0840},
	"W:WK6,24:B12,K9,K18,K17,K28", 7, EGDB_WHITE, EGDB_LOSS, {0x010c0900, 0x00100040, 0x010c0840},
	"B:W14,21:BK1,9,K28,K32,K30", 7, EGDB_BLACK, EGDB_WIN, {0x51000808, 0x00804000, 0x51000008},
	"W:W14,21:BK1,9,K28,K32,K30", 7, EGDB_WHITE, EGDB_LOSS, {0x51000808, 0x00804000, 0x51000008},
	"B:WK5,K9:BK2,K6,15,K14,19", 7, EGDB_BLACK, EGDB_WIN, {0x00026044, 0x00000880, 0x000048c4},
	"W:WK5,K9:BK2,K6,15,K14,19", 7, EGDB_WHITE, EGDB_LOSS, {0x00026044, 0x00000880, 0x000048c4},
	"B:WK6,21:BK1,8,5,K22,K29", 7, EGDB_BLACK, EGDB_WIN, {0x80400098, 0x00800040, 0x80400048},
	"W:WK6,21:BK1,8,5,K22,K29", 7, EGDB_WHITE, EGDB_LOSS, {0x80400098, 0x00800040, 0x80400048},
	"B:W20,27:BK2,7,K5,K14,24", 7, EGDB_BLACK, EGDB_WIN, {0x001040a4, 0x02010000, 0x00004084},
	"W:W20,27:BK2,7,K5,K14,24", 7, EGDB_WHITE, EGDB_LOSS, {0x001040a4, 0x02010000, 0x00004084},
	"B:WK4,K28:B5,K11,16,K15,18", 7, EGDB_BLACK, EGDB_WIN, {0x00043280, 0x01000001, 0x01002201},
	"W:WK4,K28:B5,K11,16,K15,18", 7, EGDB_WHITE, EGDB_LOSS, {0x00043280, 0x01000001, 0x01002201},
	"B:W25,K30:BK1,K15,18,17,22", 7, EGDB_BLACK, EGDB_WIN, {0x004c2008, 0x48000000, 0x40002008},
	"W:W25,K30:BK1,K15,18,17,22", 7, EGDB_WHITE, EGDB_LOSS, {0x004c2008, 0x48000000, 0x40002008},
	"B:W24,32:BK4,6,18,K23,27", 7, EGDB_BLACK, EGDB_WIN, {0x02240041, 0x10100000, 0x00200001},
	"W:W24,32:BK4,6,18,K23,27", 7, EGDB_WHITE, EGDB_LOSS, {0x02240041, 0x10100000, 0x00200001},
	"B:WK20,K29:B8,12,16,K14,13", 7, EGDB_BLACK, EGDB_WIN, {0x0000d110, 0x80010000, 0x80014000},
	"W:WK20,K29:B8,12,16,K14,13", 7, EGDB_WHITE, EGDB_LOSS, {0x0000d110, 0x80010000, 0x80014000},
	"B:WK9,29:BK10,15,14,24,22", 7, EGDB_BLACK, EGDB_WIN, {0x00506400, 0x80000800, 0x00000c00},
	"W:WK9,29:BK10,15,14,24,22", 7, EGDB_WHITE, EGDB_LOSS, {0x00506400, 0x80000800, 0x00000c00},
	"B:W8,11:B2,5,16,14,K22", 7, EGDB_BLACK, EGDB_WIN, {0x00405084, 0x00000210, 0x00400000},
	"W:W8,11:B2,5,16,14,K22", 7, EGDB_WHITE, EGDB_LOSS, {0x00405084, 0x00000210, 0x00400000},
	"B:WK24,K31:B3,12,16,15,25", 7, EGDB_BLACK, EGDB_WIN, {0x08003102, 0x20100000, 0x20100000},
	"W:WK24,K31:B3,12,16,15,25", 7, EGDB_WHITE, EGDB_LOSS, {0x08003102, 0x20100000, 0x20100000},
	"B:W12,K24:B2,9,16,19,27", 7, EGDB_BLACK, EGDB_WIN, {0x02021804, 0x00100100, 0x00100000},
	"W:W12,K24:B2,9,16,19,27", 7, EGDB_WHITE, EGDB_LOSS, {0x02021804, 0x00100100, 0x00100000},
	"B:W6,28:B1,12,13,22,21", 7, EGDB_BLACK, EGDB_WIN, {0x00c08108, 0x01000040, 0x00000000},
	"W:W6,28:B1,12,13,22,21", 7, EGDB_WHITE, EGDB_LOSS, {0x00c08108, 0x01000040, 0x00000000},
	"B:WK1,K7,K11,K30:BK8,K13,K20,K25", 8, EGDB_BLACK, EGDB_DRAW, {0x08018010, 0x40000228, 0x48018238},
	"W:WK1,K7,K11,K30:BK8,K13,K20,K25", 8, EGDB_WHITE, EGDB_DRAW, {0x08018010, 0x40000228, 0x48018238},
	"B:WK3,19,K23,K31:BK10,K14,K13,K18", 8, EGDB_BLACK, EGDB_DRAW, {0x0004c400, 0x20220002, 0x2024c402},
	"W:WK3,19,K23,K31:BK10,K14,K13,K18", 8, EGDB_WHITE, EGDB_DRAW, {0x0004c400, 0x20220002, 0x2024c402},
	"B:WK1,K11,9,29:BK4,K3,K23,K22", 8, EGDB_BLACK, EGDB_WIN, {0x00600003, 0x80000a08, 0x0060020b},
	"W:WK1,K11,9,29:BK4,K3,K23,K22", 8, EGDB_WHITE, EGDB_DRAW, {0x00600003, 0x80000a08, 0x0060020b},
	"B:W11,20,32,K31:BK4,K9,K21,K29", 8, EGDB_BLACK, EGDB_WIN, {0x80800801, 0x30010200, 0xa0800801},
	"W:W11,20,32,K31:BK4,K9,K21,K29", 8, EGDB_WHITE, EGDB_LOSS, {0x80800801, 0x30010200, 0xa0800801},
	"B:W12,10,16,14:BK3,K27,K30,K29", 8, EGDB_BLACK, EGDB_WIN, {0xc2000002, 0x00005500, 0xc2000002},
	"W:W12,10,16,14:BK3,K27,K30,K29", 8, EGDB_WHITE, EGDB_LOSS, {0xc2000002, 0x00005500, 0xc2000002},
	"B:WK3,K2,K1,24:BK4,13,K18,K25", 8, EGDB_BLACK, EGDB_DRAW, {0x08048001, 0x0010000e, 0x0804000f},
	"W:WK3,K2,K1,24:BK4,13,K18,K25", 8, EGDB_WHITE, EGDB_DRAW, {0x08048001, 0x0010000e, 0x0804000f},
	"B:WK1,14,22,K28:BK12,K16,15,K20", 8, EGDB_BLACK, EGDB_WIN, {0x00013100, 0x01404008, 0x01011108},
	"W:WK1,14,22,K28:BK12,K16,15,K20", 8, EGDB_WHITE, EGDB_DRAW, {0x00013100, 0x01404008, 0x01011108},
	"B:W9,24,K23,27:B7,K13,K21,K32", 8, EGDB_BLACK, EGDB_WIN, {0x10808020, 0x02300800, 0x10a08000},
	"W:W9,24,K23,27:B7,K13,K21,K32", 8, EGDB_WHITE, EGDB_LOSS, {0x10808020, 0x02300800, 0x10a08000},
	"B:W11,10,26,32:BK4,K3,K2,17", 8, EGDB_BLACK, EGDB_WIN, {0x00080007, 0x14000600, 0x00000007},
	"W:W11,10,26,32:BK4,K3,K2,17", 8, EGDB_WHITE, EGDB_LOSS, {0x00080007, 0x14000600, 0x00000007},
	"B:W20,K23,21,K28:BK5,9,26,K30", 8, EGDB_BLACK, EGDB_DRAW, {0x44000880, 0x01a10000, 0x41200080},
	"W:W20,K23,21,K28:BK5,9,26,K30", 8, EGDB_WHITE, EGDB_DRAW, {0x44000880, 0x01a10000, 0x41200080},
	"B:W15,13,K18,28:BK6,9,22,K27", 8, EGDB_BLACK, EGDB_WIN, {0x02400840, 0x0104a000, 0x02040040},
	"W:W15,13,K18,28:BK6,9,22,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x02400840, 0x0104a000, 0x02040040},
	"B:W9,20,22,32:B11,K10,K13,25", 8, EGDB_BLACK, EGDB_WIN, {0x08008600, 0x10410800, 0x00008400},
	"W:W9,20,22,32:B11,K10,K13,25", 8, EGDB_WHITE, EGDB_LOSS, {0x08008600, 0x10410800, 0x00008400},
	"B:W20,19,K17,21:B12,22,26,K32", 8, EGDB_BLACK, EGDB_DRAW, {0x14400100, 0x008b0000, 0x10080000},
	"W:W20,19,K17,21:B12,22,26,K32", 8, EGDB_WHITE, EGDB_WIN, {0x14400100, 0x008b0000, 0x10080000},
	"B:W13,17,32,31:B11,16,15,K30", 8, EGDB_BLACK, EGDB_WIN, {0x40003200, 0x30088000, 0x40000000},
	"W:W13,17,32,31:B11,16,15,K30", 8, EGDB_WHITE, EGDB_LOSS, {0x40003200, 0x30088000, 0x40000000},
	"B:W8,11,10,15:B1,20,22,21", 8, EGDB_BLACK, EGDB_DRAW, {0x00c10008, 0x00002610, 0x00000000},
	"W:W8,11,10,15:B1,20,22,21", 8, EGDB_WHITE, EGDB_DRAW, {0x00c10008, 0x00002610, 0x00000000},
	"B:WK5,K26,K31:BK20,K19,K17,K23,K32", 8, EGDB_BLACK, EGDB_WIN, {0x102b0000, 0x24000080, 0x342b0080},
	"W:WK5,K26,K31:BK20,K19,K17,K23,K32", 8, EGDB_WHITE, EGDB_LOSS, {0x102b0000, 0x24000080, 0x342b0080},
	"B:WK12,19,K31:BK4,K10,K17,K26,K25", 8, EGDB_BLACK, EGDB_WIN, {0x0c080401, 0x20020100, 0x2c080501},
	"W:WK12,19,K31:BK4,K10,K17,K26,K25", 8, EGDB_WHITE, EGDB_LOSS, {0x0c080401, 0x20020100, 0x2c080501},
	"B:WK8,9,30:BK1,K11,K24,K21,K25", 8, EGDB_BLACK, EGDB_WIN, {0x08900208, 0x40000810, 0x08900218},
	"W:WK8,9,30:BK1,K11,K24,K21,K25", 8, EGDB_WHITE, EGDB_LOSS, {0x08900208, 0x40000810, 0x08900218},
	"B:W11,16,32:BK20,K19,K17,K27,K26", 8, EGDB_BLACK, EGDB_WIN, {0x060b0000, 0x10001200, 0x060b0000},
	"W:W11,16,32:BK20,K19,K17,K27,K26", 8, EGDB_WHITE, EGDB_LOSS, {0x060b0000, 0x10001200, 0x060b0000},
	"B:WK4,K3,K2:B13,K17,K24,K28,K27", 8, EGDB_BLACK, EGDB_WIN, {0x03188000, 0x00000007, 0x03180007},
	"W:WK4,K3,K2:B13,K17,K24,K28,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x03188000, 0x00000007, 0x03180007},
	"B:WK3,K2,24:BK4,K1,K8,15,K19", 8, EGDB_BLACK, EGDB_WIN, {0x00022019, 0x00100006, 0x0002001f},
	"W:WK3,K2,24:BK4,K1,K8,15,K19", 8, EGDB_WHITE, EGDB_LOSS, {0x00022019, 0x00100006, 0x0002001f},
	"B:W15,20,K17:BK7,K9,K28,27,K32", 8, EGDB_BLACK, EGDB_WIN, {0x13000820, 0x00092000, 0x11080820},
	"W:W15,20,K17:BK7,K9,K28,27,K32", 8, EGDB_WHITE, EGDB_LOSS, {0x13000820, 0x00092000, 0x11080820},
	"B:W10,18,27:BK4,K3,K12,17,K26", 8, EGDB_BLACK, EGDB_WIN, {0x04080103, 0x02040400, 0x04000103},
	"W:W10,18,27:BK4,K3,K12,17,K26", 8, EGDB_WHITE, EGDB_LOSS, {0x04080103, 0x02040400, 0x04000103},
	"B:WK8,K5,K24:BK11,K15,13,19,K26", 8, EGDB_BLACK, EGDB_WIN, {0x0402a200, 0x00100090, 0x04102290},
	"W:WK8,K5,K24:BK11,K15,13,19,K26", 8, EGDB_WHITE, EGDB_LOSS, {0x0402a200, 0x00100090, 0x04102290},
	"B:WK1,21,K28:BK12,11,16,K14,K20", 8, EGDB_BLACK, EGDB_WIN, {0x00015300, 0x01800008, 0x01014108},
	"W:WK1,21,K28:BK12,11,16,K14,K20", 8, EGDB_WHITE, EGDB_LOSS, {0x00015300, 0x01800008, 0x01014108},
	"B:W20,21,K25:BK6,9,26,K32,K30", 8, EGDB_BLACK, EGDB_WIN, {0x54000840, 0x08810000, 0x58000040},
	"W:W20,21,K25:BK6,9,26,K32,K30", 8, EGDB_WHITE, EGDB_LOSS, {0x54000840, 0x08810000, 0x58000040},
	"B:W16,20,24:BK3,K21,28,K27,25", 8, EGDB_BLACK, EGDB_WIN, {0x0b800002, 0x00111000, 0x02800002},
	"W:W16,20,24:BK3,K21,28,K27,25", 8, EGDB_WHITE, EGDB_LOSS, {0x0b800002, 0x00111000, 0x02800002},
	"B:WK7,K26,K25:BK16,14,20,18,K27", 8, EGDB_BLACK, EGDB_WIN, {0x02055000, 0x0c000020, 0x0e001020},
	"W:WK7,K26,K25:BK16,14,20,18,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x02055000, 0x0c000020, 0x0e001020},
	"B:WK6,K12,25:BK4,13,20,K17,27", 8, EGDB_BLACK, EGDB_WIN, {0x02098001, 0x08000140, 0x00080141},
	"W:WK6,K12,25:BK4,13,20,K17,27", 8, EGDB_WHITE, EGDB_LOSS, {0x02098001, 0x08000140, 0x00080141},
	"B:WK1,24,29:BK4,K12,9,13,18", 8, EGDB_BLACK, EGDB_WIN, {0x00048901, 0x80100008, 0x00000109},
	"W:WK1,24,29:BK4,K12,9,13,18", 8, EGDB_WHITE, EGDB_LOSS, {0x00048901, 0x80100008, 0x00000109},
	"B:W20,19,21:BK5,12,22,26,K30", 8, EGDB_BLACK, EGDB_WIN, {0x44400180, 0x00830000, 0x40000080},
	"W:W20,19,21:BK5,12,22,26,K30", 8, EGDB_WHITE, EGDB_LOSS, {0x44400180, 0x00830000, 0x40000080},
	"B:WK4,K3,K2:B8,12,14,13,K27", 8, EGDB_BLACK, EGDB_WIN, {0x0200c110, 0x00000007, 0x02000007},
	"W:WK4,K3,K2:B8,12,14,13,K27", 8, EGDB_WHITE, EGDB_LOSS, {0x0200c110, 0x00000007, 0x02000007},
	"B:WK3,K2,29:BK4,11,10,19,28", 8, EGDB_BLACK, EGDB_WIN, {0x01020601, 0x80000006, 0x00000007},
	"W:WK3,K2,29:BK4,11,10,19,28", 8, EGDB_WHITE, EGDB_LOSS, {0x01020601, 0x80000006, 0x00000007},
	"B:WK4,31,30:B6,5,16,K20,21", 8, EGDB_BLACK, EGDB_WIN, {0x008110c0, 0x60000001, 0x00010001},
	"W:WK4,31,30:B6,5,16,K20,21", 8, EGDB_WHITE, EGDB_LOSS, {0x008110c0, 0x60000001, 0x00010001},
	"B:W8,10,9:B2,7,K15,13,18", 8, EGDB_BLACK, EGDB_WIN, {0x0004a024, 0x00000c10, 0x00002000},
	"W:W8,10,9:B2,7,K15,13,18", 8, EGDB_WHITE, EGDB_LOSS, {0x0004a024, 0x00000c10, 0x00002000},
	"B:WK5,K27,K26:B1,8,16,13,25", 8, EGDB_BLACK, EGDB_DRAW, {0x08009018, 0x06000080, 0x06000080},
	"W:WK5,K27,K26:B1,8,16,13,25", 8, EGDB_WHITE, EGDB_WIN, {0x08009018, 0x06000080, 0x06000080},
	"B:WK6,12,K27:B3,15,19,28,25", 8, EGDB_BLACK, EGDB_WIN, {0x09022002, 0x02000140, 0x02000040},
	"W:WK6,12,K27:B3,15,19,28,25", 8, EGDB_WHITE, EGDB_DRAW, {0x09022002, 0x02000140, 0x02000040},
	"B:W6,23,K25:B4,12,10,18,21", 8, EGDB_BLACK, EGDB_WIN, {0x00840501, 0x08200040, 0x08000000},
	"W:W6,23,K25:B4,12,10,18,21", 8, EGDB_WHITE, EGDB_LOSS, {0x00840501, 0x08200040, 0x08000000},
	"B:W7,25,32:B1,6,20,18,21", 8, EGDB_BLACK, EGDB_WIN, {0x00850048, 0x18000020, 0x00000000},
	"W:W7,25,32:B1,6,20,18,21", 8, EGDB_WHITE, EGDB_LOSS, {0x00850048, 0x18000020, 0x00000000},
	"B:WK2,K8,K23,K30:BK16,K15,K13,K17,K32", 9, EGDB_BLACK, EGDB_WIN, {0x1008b000, 0x40200014, 0x5028b014},
	"B:WK11,K9,K14,19:BK4,K8,K16,K23,K27", 9, EGDB_BLACK, EGDB_WIN, {0x02201011, 0x00024a00, 0x02205a11},
	"B:WK4,9,K16,30:BK1,K11,K24,K21,K25", 9, EGDB_BLACK, EGDB_WIN, {0x08900208, 0x40001801, 0x08901209},
	"B:W11,K10,9,14:BK12,K16,K20,K23,K28", 9, EGDB_BLACK, EGDB_WIN, {0x01211100, 0x00004e00, 0x01211500},
	"B:W12,10,16,15:BK4,K3,K2,K1,K8", 9, EGDB_BLACK, EGDB_WIN, {0x0000001f, 0x00003500, 0x0000001f},
	"B:WK7,K15,K21,K25:BK8,K9,14,K24,K23", 9, EGDB_BLACK, EGDB_WIN, {0x00304810, 0x08802020, 0x08b02830},
	"B:WK4,K3,K2,24:BK10,13,K17,K21,K32", 9, EGDB_BLACK, EGDB_WIN, {0x10888400, 0x00100007, 0x10880407},
	"B:WK10,15,20,K21:BK7,K9,K28,27,K32", 9, EGDB_BLACK, EGDB_WIN, {0x13000820, 0x00812400, 0x11800c20},
	"B:WK2,10,18,27:BK4,K3,K12,17,K26", 9, EGDB_BLACK, EGDB_WIN, {0x04080103, 0x02040404, 0x04000107},
	"B:W11,10,26,32:BK4,K3,K2,K1,17", 9, EGDB_BLACK, EGDB_WIN, {0x0008000f, 0x14000600, 0x0000000f},
	"W:WK17,K24,K25,K32:BK12,K15,14,19,K23", 9, EGDB_WHITE, EGDB_DRAW, {0x00226100, 0x18180000, 0x18382100},
	"B:WK3,K13,21,K29:BK1,20,24,K28,K27", 9, EGDB_BLACK, EGDB_WIN, {0x03110008, 0x80808002, 0x8300800a},
	"B:WK15,20,21,K31:BK6,9,26,K32,K30", 9, EGDB_BLACK, EGDB_WIN, {0x54000840, 0x20812000, 0x70002040},
	"B:WK4,16,20,24:BK3,K21,28,K27,25", 9, EGDB_BLACK, EGDB_WIN, {0x0b800002, 0x00111001, 0x02800003},
	"B:W9,14,24,27:BK4,K3,K2,12,25", 9, EGDB_BLACK, EGDB_WIN, {0x08000107, 0x02104800, 0x00000007},
	"W:WK3,K1,K21,K25:BK12,15,14,18,K32", 9, EGDB_WHITE, EGDB_DRAW, {0x10046100, 0x0880000a, 0x1880010a},
	"W:WK9,K16,K17,26:B10,14,13,K18,K24", 9, EGDB_WHITE, EGDB_WIN, {0x0014c400, 0x04081800, 0x001c1800},
	"B:WK2,K5,17,21:BK8,K7,11,28,26", 9, EGDB_BLACK, EGDB_WIN, {0x05000230, 0x00880084, 0x000000b4},
	"B:W20,19,K23,21:BK2,K8,11,22,26", 9, EGDB_BLACK, EGDB_WIN, {0x04400214, 0x00a30000, 0x00200014},
	"B:W14,25,30,29:BK4,K3,7,16,20", 9, EGDB_BLACK, EGDB_WIN, {0x00011023, 0xc8004000, 0x00000003},
	"W:WK4,K3,K2,K1:B8,12,14,13,K27", 9, EGDB_WHITE, EGDB_DRAW, {0x0200c110, 0x0000000f, 0x0200000f},
	"W:WK3,K2,K1,29:BK4,11,10,19,28", 9, EGDB_WHITE, EGDB_DRAW, {0x01020601, 0x8000000e, 0x0000000f},
	"B:WK3,K2,26,30:BK4,17,23,28,25", 9, EGDB_BLACK, EGDB_WIN, {0x09280001, 0x44000006, 0x00000007},
	"B:W8,12,9,K21:B2,16,17,K22,28", 9, EGDB_BLACK, EGDB_WIN, {0x01481004, 0x00800910, 0x00c00000},
	"B:W8,11,19,27:BK4,3,5,9,20", 9, EGDB_BLACK, EGDB_WIN, {0x00010883, 0x02020210, 0x00000001},
	"W:WK4,K14,K21,K27:B2,15,20,18,25", 9, EGDB_WHITE, EGDB_WIN, {0x08052004, 0x02804001, 0x02804001},
	"W:WK3,K2,K1,5:B4,16,20,18,28", 9, EGDB_WHITE, EGDB_DRAW, {0x01051001, 0x0000008e, 0x0000000e},
	"W:W6,K5,16,K13:B1,15,20,23,27", 9, EGDB_WHITE, EGDB_DRAW, {0x02212008, 0x000090c0, 0x00008080},
	"B:WK2,7,25,32:B1,20,19,18,21", 9, EGDB_BLACK, EGDB_WIN, {0x00870008, 0x18000024, 0x00000004},
	"B:W6,15,28,29:B4,8,9,18,25", 9, EGDB_BLACK, EGDB_DRAW, {0x08040811, 0x81002040, 0x00000000},
	"W:W6,15,28,29:B4,8,9,18,25", 9, EGDB_WHITE, EGDB_DRAW, {0x08040811, 0x81002040, 0x00000000},
	"B:WK3,K2,K22,K26,K30:BK16,K15,K13,K17,K32", 10, EGDB_BLACK, EGDB_DRAW, {0x1008b000, 0x44400006, 0x5448b006},
	"W:WK3,K2,K22,K26,K30:BK16,K15,K13,K17,K32", 10, EGDB_WHITE, EGDB_DRAW, {0x1008b000, 0x44400006, 0x5448b006},
	"W:WK1,K10,K14,19,K18:BK4,K8,K16,K23,K27", 10, EGDB_WHITE, EGDB_DRAW, {0x02201011, 0x00064408, 0x02245419},
	"B:WK2,9,K19,28,K29:BK4,K16,K24,K31,K30", 10, EGDB_BLACK, EGDB_WIN, {0x60101001, 0x81020804, 0xe0121005},
	"B:W11,K15,20,19,K31:BK1,K5,K10,K18,K29", 10, EGDB_BLACK, EGDB_WIN, {0x80040488, 0x20032200, 0xa0042488},
	"B:WK4,5,22,32,31:BK8,K16,K14,K24,K21", 10, EGDB_BLACK, EGDB_WIN, {0x00905010, 0x30400081, 0x00905011},
	"B:W5,10,16,25,32:BK4,K17,K22,K21,K31", 10, EGDB_BLACK, EGDB_WIN, {0x20c80001, 0x18001480, 0x20c80001},
	"B:WK4,K3,K2,K1,24:BK10,13,K17,K21,K32", 10, EGDB_BLACK, EGDB_DRAW, {0x10888400, 0x0010000f, 0x1088040f},
	"W:WK4,K3,K2,K1,24:BK10,13,K17,K21,K32", 10, EGDB_WHITE, EGDB_DRAW, {0x10888400, 0x0010000f, 0x1088040f},
	"W:WK6,K16,15,20,K25:BK7,K9,K28,27,K32", 10, EGDB_WHITE, EGDB_DRAW, {0x13000820, 0x08013040, 0x19001860},
	"B:WK2,K1,10,18,27:BK4,K3,K12,17,K26", 10, EGDB_BLACK, EGDB_WIN, {0x04080103, 0x0204040c, 0x0400010f},
	"B:WK8,11,10,26,32:BK4,K3,K2,K1,17", 10, EGDB_BLACK, EGDB_WIN, {0x0008000f, 0x14000610, 0x0000001f},
	"B:W12,14,18,17,31:B6,K20,K21,K28,K27", 10, EGDB_BLACK, EGDB_WIN, {0x03810040, 0x200c4100, 0x03810000},
	"B:WK3,K8,14,K18,31:BK1,K16,K20,17,25", 10, EGDB_BLACK, EGDB_DRAW, {0x08091008, 0x20044012, 0x0005101a},
	"W:WK3,K8,14,K18,31:BK1,K16,K20,17,25", 10, EGDB_WHITE, EGDB_DRAW, {0x08091008, 0x20044012, 0x0005101a},
	"B:WK4,K2,16,20,24:BK3,K21,28,K27,25", 10, EGDB_BLACK, EGDB_WIN, {0x0b800002, 0x00111005, 0x02800007},
	"B:WK1,9,14,24,27:BK4,K3,K2,12,25", 10, EGDB_BLACK, EGDB_WIN, {0x08000107, 0x02104808, 0x0000000f},
	"B:W11,16,17,24,21:BK1,14,K13,28,K30", 10, EGDB_BLACK, EGDB_WIN, {0x4100c008, 0x00981200, 0x40008008},
	"B:W20,K17,21,28,K25:BK4,K5,10,14,19", 10, EGDB_BLACK, EGDB_DRAW, {0x00024481, 0x09890000, 0x08080081},
	"W:W20,K17,21,28,K25:BK4,K5,10,14,19", 10, EGDB_WHITE, EGDB_DRAW, {0x00024481, 0x09890000, 0x08080081},
	"B:WK2,14,25,30,29:BK4,K3,7,16,20", 10, EGDB_BLACK, EGDB_WIN, {0x00011023, 0xc8004004, 0x00000007},
	"B:W9,19,23,32,29:BK11,K18,17,24,21", 10, EGDB_BLACK, EGDB_WIN, {0x009c0200, 0x90220800, 0x00040200},
	"B:W8,11,19,K22,27:B3,5,K10,9,20", 10, EGDB_BLACK, EGDB_DRAW, {0x00010c82, 0x02420210, 0x00400400},
	"W:W8,11,19,K22,27:B3,5,K10,9,20", 10, EGDB_WHITE, EGDB_DRAW, {0x00010c82, 0x02420210, 0x00400400},
	"B:W18,28,26,32,31:B7,K5,11,15,24", 10, EGDB_BLACK, EGDB_WIN, {0x001022a0, 0x35040000, 0x00000080},
	"W:W18,28,26,32,31:B7,K5,11,15,24", 10, EGDB_WHITE, EGDB_LOSS, {0x001022a0, 0x35040000, 0x00000080},
	"B:W6,10,14,18,25:B4,8,16,20,26", 10, EGDB_BLACK, EGDB_DRAW, {0x04011011, 0x08044440, 0x00000000},
	"W:W6,10,14,18,25:B4,8,16,20,26", 10, EGDB_WHITE, EGDB_DRAW, {0x04011011, 0x08044440, 0x00000000},
#endif
};

const int num_positions = sizeof(positions) / sizeof(positions[0]);
